@@ -7,6 +7,19 @@ import (
 	"github.com/acorn-io/acorn/pkg/client"
 )
 
+func NewImageWithSidecar(t *testing.T, namespace string) string {
+	t.Helper()
+
+	c := helper.BuilderClient(t, namespace)
+	image, err := c.AcornImageBuild(helper.GetCTX(t), "../testdata/sidecar/Acornfile", &client.AcornImageBuildOptions{
+		Cwd: "../testdata/sidecar",
+	})
+	if err != nil {
+		t.Fatal(err)
+	}
+	return image.ID
+}
+
 func NewImage2(t *testing.T, namespace string) string {
 	t.Helper()
 
