@@ -106,7 +106,7 @@ func TestFriendlyNameInContainer(t *testing.T) {
 	}
 
 	helper.WaitForObject(t, client.Watch, &apiv1.AppList{}, appInstance, func(obj *apiv1.App) bool {
-		return obj.Status.ContainerStatus["default"].Ready == 1
+		return obj.Status.AppStatus.Containers["default"].ReadyReplicaCount == 1
 	})
 
 	c, err = hclient.New(cfg, "", ns.Name)
@@ -121,6 +121,6 @@ func TestFriendlyNameInContainer(t *testing.T) {
 
 	_, img, _ := strings.Cut(image.ImageData.Containers["default"].Image, "@")
 	assert.Len(t, cs, 1)
-	assert.Equal(t, "public.ecr.aws/docker/library/nginx:latest", cs[0].Spec.Image)
+	assert.Equal(t, "ghcr.io/acorn-io/images-mirror/nginx:latest", cs[0].Spec.Image)
 	assert.True(t, strings.HasSuffix(cs[0].Status.ImageID, img))
 }
