@@ -47,7 +47,7 @@ func TestImageListGetDelete(t *testing.T) {
 
 	assert.Equal(t, image.Name, newImage.Name)
 
-	delImage, err := c.ImageDelete(ctx, image.Name, &client.ImageDeleteOptions{Force: false})
+	delImage, _, err := c.ImageDelete(ctx, image.Name, &client.ImageDeleteOptions{Force: false})
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -119,17 +119,17 @@ func TestImageTag(t *testing.T) {
 
 	image := images[0]
 
-	err = c.ImageTag(ctx, image.Name, "foo")
+	err = c.ImageTag(ctx, image.Name, "foo:latest")
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	err = c.ImageTag(ctx, "foo", "bar")
+	err = c.ImageTag(ctx, "foo:latest", "bar:latest")
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	err = c.ImageTag(ctx, "foo", "ghcr.io/acorn-io/acorn/test:v0.0.0-abc")
+	err = c.ImageTag(ctx, "foo:latest", "ghcr.io/acorn-io/acorn/test:v0.0.0-abc")
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -363,11 +363,11 @@ func TestImageDeleteTwoTags(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	_, err = c.ImageDelete(ctx, image.Name, &client.ImageDeleteOptions{Force: false})
+	_, _, err = c.ImageDelete(ctx, image.Name, &client.ImageDeleteOptions{Force: false})
 	expectedErr := fmt.Errorf("unable to delete %s (must be forced) - image is referenced in multiple repositories", image.Name)
 	assert.Equal(t, expectedErr, err)
 
-	_, err = c.ImageDelete(ctx, image.Name, &client.ImageDeleteOptions{Force: true})
+	_, _, err = c.ImageDelete(ctx, image.Name, &client.ImageDeleteOptions{Force: true})
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -404,9 +404,8 @@ func TestImageBadTag(t *testing.T) {
 	assert.Equal(t, "sha256:"+image.Name, image.Digest)
 
 	err = c.ImageTag(ctx, image.Name, "foo:a@badtag")
-	assert.Equal(t, "tag can only contain the characters `abcdefghijklmnopqrstuvwxyz0123456789_-.ABCDEFGHIJKLMNOPQRSTUVWXYZ`: a@badtag", err.Error())
+	assert.Equal(t, "could not parse reference: foo:a@badtag", err.Error())
 
 	err = c.ImageTag(ctx, image.Name, "foo@@:badtag")
-	assert.Equal(t, "repository can only contain the characters `abcdefghijklmnopqrstuvwxyz0123456789_-./`: foo@@", err.Error())
-
+	assert.Equal(t, "could not parse reference: foo@@:badtag", err.Error())
 }
