@@ -10,6 +10,7 @@ import (
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/client"
 	"github.com/acorn-io/acorn/pkg/dev"
+	"github.com/acorn-io/acorn/pkg/imagesource"
 	hclient "github.com/acorn-io/acorn/pkg/k8sclient"
 	"github.com/acorn-io/baaah/pkg/watcher"
 	"golang.org/x/sync/errgroup"
@@ -20,10 +21,10 @@ const (
 containers: default: build: {}
 `
 	dockerfile1 = `
-FROM public.ecr.aws/docker/library/busybox:latest
+FROM ghcr.io/acorn-io/images-mirror/busybox:latest
 CMD ["echo", "hi"]`
 	dockerfile2 = `
-FROM public.ecr.aws/docker/library/busybox:latest
+FROM ghcr.io/acorn-io/images-mirror/busybox:latest
 CMD ["echo", "bye"]`
 )
 
@@ -58,10 +59,8 @@ func TestDev(t *testing.T) {
 
 	eg := errgroup.Group{}
 	eg.Go(func() error {
-		return dev.Dev(subCtx, helper.BuilderClient(t, ns.Name), acornCueFile, &dev.Options{
-			Build: client.AcornImageBuildOptions{
-				Cwd: tmp,
-			},
+		return dev.Dev(subCtx, helper.BuilderClient(t, ns.Name), &dev.Options{
+			ImageSource: imagesource.NewImageSource(acornCueFile, []string{tmp}, nil, nil),
 			Run: client.AppRunOptions{
 				Name: "test-app",
 			},
@@ -82,7 +81,7 @@ func TestDev(t *testing.T) {
 	}
 
 	_, err = appWatcher.ByName(ctx, ns.Name, "test-app", func(app *v1.AppInstance) (bool, error) {
-		return app.Spec.Image != oldImage && app.Spec.Image != "", nil
+		return app.Spec.Image == oldImage && app.Status.DevSession != nil && app.Status.DevSession.SpecOverride.Image != "", nil
 	})
 	if err != nil {
 		t.Fatal(err)
