@@ -8,6 +8,7 @@ import (
 
 	"github.com/acorn-io/acorn/integration/helper"
 	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
+	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/client"
 	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
@@ -33,7 +34,20 @@ func TestLog(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	app, err := c.AppRun(context.Background(), image.ID, nil)
+	app, err := c.AppRun(context.Background(), image.ID, &client.AppRunOptions{
+		/* When running this test with the acorn-linkerd-plugin installed, the app inits too quickly, and
+		   the acorn controller does not have enough time to propagate the injection annotation to the
+		   test namespace before the app is created, so linkerd does not end up injecting the sidecar.
+		   For this reason, we add the annotation here so that it will be placed directly on the app's
+		   pods, and the linkerd sidecars will be injected. In clusters without linkerd installed,
+		   this annotation will have zero effect. */
+		Annotations: []v1.ScopedLabel{
+			{
+				Key:   "linkerd.io/inject",
+				Value: "enabled",
+			},
+		},
+	})
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -42,8 +56,8 @@ func TestLog(t *testing.T) {
 	defer cancel()
 
 	app = helper.WaitForObject(t, helper.Watcher(t, c), &apiv1.AppList{}, app, func(app *apiv1.App) bool {
-		return app.Status.ContainerStatus["cont1-1"].Ready == 1 &&
-			app.Status.ContainerStatus["cont1-2"].Ready == 1
+		return app.Status.AppStatus.Containers["cont1-1"].ReadyReplicaCount == 1 &&
+			app.Status.AppStatus.Containers["cont1-2"].ReadyReplicaCount == 1
 	})
 
 	output, err := c.AppLog(ctx, app.Name, nil)
@@ -87,8 +101,8 @@ func TestContainerLog(t *testing.T) {
 	defer cancel()
 
 	app = helper.WaitForObject(t, helper.Watcher(t, c), &apiv1.AppList{}, app, func(app *apiv1.App) bool {
-		return app.Status.ContainerStatus["cont1-1"].Ready == 1 &&
-			app.Status.ContainerStatus["cont1-2"].Ready == 1
+		return app.Status.AppStatus.Containers["cont1-1"].ReadyReplicaCount == 1 &&
+			app.Status.AppStatus.Containers["cont1-2"].ReadyReplicaCount == 1
 	})
 
 	replicas, err := c.ContainerReplicaList(ctx, &client.ContainerReplicaListOptions{
@@ -145,8 +159,8 @@ func TestSidecarContainerLog(t *testing.T) {
 	defer cancel()
 
 	app = helper.WaitForObject(t, helper.Watcher(t, c), &apiv1.AppList{}, app, func(app *apiv1.App) bool {
-		return app.Status.ContainerStatus["cont1-1"].Ready == 1 &&
-			app.Status.ContainerStatus["cont1-2"].Ready == 1
+		return app.Status.AppStatus.Containers["cont1-1"].ReadyReplicaCount == 1 &&
+			app.Status.AppStatus.Containers["cont1-2"].ReadyReplicaCount == 1
 	})
 
 	replicas, err := c.ContainerReplicaList(ctx, &client.ContainerReplicaListOptions{
@@ -182,5 +196,5 @@ func TestSidecarContainerLog(t *testing.T) {
 
 	sort.Strings(lines)
 	assert.Equal(t, "line 1-3\nline 1-4", strings.Join(lines, "\n"))
-	assert.Len(t, strings.Split(replicas[1].Name, "."), 3)
+	assert.Len(t, strings.Split(replicas[1].Name, ":"), 2)
 }
