@@ -10,19 +10,22 @@ import (
 type AppInstanceCondition string
 
 var (
-	AppInstanceConditionDefined    = "defined"
-	AppInstanceConditionDefaults   = "defaults"
-	AppInstanceConditionScheduling = "scheduling"
-	AppInstanceConditionNamespace  = "namespace"
-	AppInstanceConditionParsed     = "parsed"
-	AppInstanceConditionController = "controller"
-	AppInstanceConditionPulled     = "image-pull"
-	AppInstanceConditionSecrets    = "secrets"
-	AppInstanceConditionContainers = "containers"
-	AppInstanceConditionJobs       = "jobs"
-	AppInstanceConditionReady      = "Ready"
-	AppInstanceConditionUpgrade    = "upgrade"
-	AppInstanceConditionVolumes    = "volumes"
+	AppInstanceConditionDefined        = "defined"
+	AppInstanceConditionDefaults       = "defaults"
+	AppInstanceConditionScheduling     = "scheduling"
+	AppInstanceConditionNamespace      = "namespace"
+	AppInstanceConditionParsed         = "parsed"
+	AppInstanceConditionController     = "controller"
+	AppInstanceConditionPulled         = "image-pull"
+	AppInstanceConditionSecrets        = "secrets"
+	AppInstanceConditionServices       = "services"
+	AppInstanceConditionContainers     = "containers"
+	AppInstanceConditionJobs           = "jobs"
+	AppInstanceConditionAcorns         = "acorns"
+	AppInstanceConditionReady          = "Ready"
+	AppInstanceConditionVolumes        = "volumes"
+	AppInstanceConditionImageAllowed   = "image-allowed"
+	AppInstanceConditionQuotaAllocated = "quota-allocated"
 )
 
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
@@ -43,6 +46,27 @@ type AppInstance struct {
 	Status AppInstanceStatus `json:"status,omitempty"`
 }
 
+func (in *AppInstance) HasRegion(region string) bool {
+	return in.Status.Defaults.Region == region || in.Spec.Region == region
+}
+
+func (in *AppInstance) GetRegion() string {
+	if in.Spec.Region != "" {
+		return in.Spec.Region
+	}
+	return in.Status.Defaults.Region
+}
+
+func (in *AppInstance) SetDefaultRegion(region string) {
+	if in.Spec.Region == "" {
+		if in.Status.Defaults.Region == "" {
+			in.Status.Defaults.Region = region
+		}
+	} else {
+		in.Status.Defaults.Region = ""
+	}
+}
+
 func (in *AppInstance) ShortID() string {
 	if len(in.UID) > 11 {
 		return string(in.UID[:12])
@@ -59,11 +83,11 @@ const (
 )
 
 type AppInstanceSpec struct {
+	Region              string           `json:"region,omitempty"`
 	Labels              []ScopedLabel    `json:"labels,omitempty"`
 	Annotations         []ScopedLabel    `json:"annotations,omitempty"`
 	Image               string           `json:"image,omitempty"`
 	Stop                *bool            `json:"stop,omitempty"`
-	DevMode             *bool            `json:"devMode,omitempty"`
 	Profiles            []string         `json:"profiles,omitempty"`
 	Volumes             []VolumeBinding  `json:"volumes,omitempty"`
 	Secrets             []SecretBinding  `json:"secrets,omitempty"`
@@ -71,16 +95,20 @@ type AppInstanceSpec struct {
 	PublishMode         PublishMode      `json:"publishMode,omitempty"`
 	TargetNamespace     string           `json:"targetNamespace,omitempty"`
 	Links               []ServiceBinding `json:"services,omitempty"`
-	Ports               []PortBinding    `json:"ports,omitempty"`
+	Publish             []PortBinding    `json:"ports,omitempty"`
 	DeployArgs          GenericMap       `json:"deployArgs,omitempty"`
 	Permissions         []Permissions    `json:"permissions,omitempty"`
 	AutoUpgrade         *bool            `json:"autoUpgrade,omitempty"`
 	NotifyUpgrade       *bool            `json:"notifyUpgrade,omitempty"`
 	AutoUpgradeInterval string           `json:"autoUpgradeInterval,omitempty"`
-	ComputeClass        ComputeClassMap  `json:"computeClass,omitempty"`
+	ComputeClasses      ComputeClassMap  `json:"computeClass,omitempty"`
 	Memory              MemoryMap        `json:"memory,omitempty"`
 }
 
+func (in *AppInstanceSpec) GetStopped() bool {
+	return in.Stop != nil && *in.Stop
+}
+
 func (in *AppInstanceSpec) GetAutoUpgrade() bool {
 	return in.AutoUpgrade != nil && *in.AutoUpgrade
 }
@@ -89,12 +117,8 @@ func (in *AppInstanceSpec) GetNotifyUpgrade() bool {
 	return in.NotifyUpgrade != nil && *in.NotifyUpgrade
 }
 
-func (in *AppInstanceSpec) GetDevMode() bool {
-	return in.DevMode != nil && *in.DevMode
-}
-
-func (in *AppInstanceSpec) GetProfiles() []string {
-	if in.GetDevMode() {
+func (in *AppInstanceSpec) GetProfiles(devMode bool) []string {
+	if devMode {
 		found := false
 		for _, profile := range in.Profiles {
 			if profile == "dev?" {
@@ -109,11 +133,15 @@ func (in *AppInstanceSpec) GetProfiles() []string {
 	return in.Profiles
 }
 
+type ServiceBindings []ServiceBinding
+
 type ServiceBinding struct {
 	Target  string `json:"target,omitempty"`
 	Service string `json:"service,omitempty"`
 }
 
+type SecretBindings []SecretBinding
+
 type SecretBinding struct {
 	Secret string `json:"secret,omitempty"`
 	Target string `json:"target,omitempty"`
@@ -121,6 +149,8 @@ type SecretBinding struct {
 
 type Quantity string
 
+type VolumeBindings []VolumeBinding
+
 type VolumeBinding struct {
 	Volume      string      `json:"volume,omitempty"`
 	Target      string      `json:"target,omitempty"`
@@ -129,21 +159,6 @@ type VolumeBinding struct {
 	Class       string      `json:"class,omitempty"`
 }
 
-type ContainerStatus struct {
-	Ready        int32 `json:"ready,omitempty"`
-	ReadyDesired int32 `json:"readyDesired,omitempty"`
-	UpToDate     int32 `json:"upToDate,omitempty"`
-	RestartCount int32 `json:"restartCount,omitempty"`
-	Created      bool  `json:"created,omitempty"`
-}
-
-type JobStatus struct {
-	Succeed bool   `json:"succeed,omitempty"`
-	Failed  bool   `json:"failed,omitempty"`
-	Running bool   `json:"running,omitempty"`
-	Message string `json:"message,omitempty"`
-}
-
 type AppColumns struct {
 	Healthy   string `json:"healthy,omitempty" column:"name=Healthy,jsonpath=.status.columns.healthy"`
 	UpToDate  string `json:"upToDate,omitempty" column:"name=Up-To-Date,jsonpath=.status.columns.upToDate"`
@@ -152,27 +167,33 @@ type AppColumns struct {
 	Created   string `json:"created,omitempty" column:"name=Created,jsonpath=.metadata.creationTimestamp"`
 }
 
+func (a AppInstanceStatus) GetDevMode() bool {
+	return a.DevSession != nil
+}
+
 type AppInstanceStatus struct {
-	ObservedGeneration     int64                      `json:"observedGeneration,omitempty"`
-	Columns                AppColumns                 `json:"columns,omitempty"`
-	ContainerStatus        map[string]ContainerStatus `json:"containerStatus,omitempty"`
-	JobsStatus             map[string]JobStatus       `json:"jobsStatus,omitempty"`
-	Ready                  bool                       `json:"ready,omitempty"`
-	Stopped                bool                       `json:"stopped,omitempty"`
-	Namespace              string                     `json:"namespace,omitempty"`
-	AppImage               AppImage                   `json:"appImage,omitempty"`
-	AvailableAppImage      string                     `json:"availableAppImage,omitempty"`
-	ConfirmUpgradeAppImage string                     `json:"confirmUpgradeAppImage,omitempty"`
-	AppSpec                AppSpec                    `json:"appSpec,omitempty"`
-	Scheduling             map[string]Scheduling      `json:"scheduling,omitempty"`
-	Conditions             []Condition                `json:"conditions,omitempty"`
-	Endpoints              []Endpoint                 `json:"endpoints,omitempty"`
-	Defaults               Defaults                   `json:"defaults,omitempty"`
+	DevSession                   *DevSessionInstanceSpec `json:"devSession,omitempty"`
+	ObservedGeneration           int64                   `json:"observedGeneration,omitempty"`
+	ObservedImageDigest          string                  `json:"observedImageDigest,omitempty"`
+	Columns                      AppColumns              `json:"columns,omitempty"`
+	Ready                        bool                    `json:"ready,omitempty"`
+	Namespace                    string                  `json:"namespace,omitempty"`
+	AppImage                     AppImage                `json:"appImage,omitempty"`
+	AvailableAppImage            string                  `json:"availableAppImage,omitempty"`
+	AvailableAppImageRemote      bool                    `json:"availableAppImageRemote,omitempty"`
+	ConfirmUpgradeAppImage       string                  `json:"confirmUpgradeAppImage,omitempty"`
+	ConfirmUpgradeAppImageRemote bool                    `json:"confirmUpgradeAppImageRemote,omitempty"`
+	AppSpec                      AppSpec                 `json:"appSpec,omitempty"`
+	AppStatus                    AppStatus               `json:"appStatus,omitempty"`
+	Scheduling                   map[string]Scheduling   `json:"scheduling,omitempty"`
+	Conditions                   []Condition             `json:"conditions,omitempty"`
+	Defaults                     Defaults                `json:"defaults,omitempty"`
 }
 
 type Defaults struct {
 	Volumes map[string]VolumeDefault `json:"volumes,omitempty"`
 	Memory  map[string]*int64        `json:"memory,omitempty"`
+	Region  string                   `json:"region,omitempty"`
 }
 
 type VolumeDefault struct {
