@@ -17,6 +17,16 @@ type ImagesData struct {
 	Containers map[string]ContainerData `json:"containers,omitempty"`
 	Jobs       map[string]ContainerData `json:"jobs,omitempty"`
 	Images     map[string]ImageData     `json:"images,omitempty"`
+	Acorns     map[string]ImageData     `json:"acorns,omitempty"`
+	Builds     []BuildRecord            `json:"builds,omitempty"`
+}
+
+type BuildRecord struct {
+	AcornBuild     *AcornBuilderSpec          `json:"acornBuild,omitempty"`
+	AcornAppImage  *AppImage                  `json:"acornAppImage,omitempty"`
+	ContainerBuild *ContainerImageBuilderSpec `json:"containerBuild,omitempty"`
+	ImageBuild     *ImageBuilderSpec          `json:"imageBuild,omitempty"`
+	ImageKey       string                     `json:"imageKey,omitempty"`
 }
 
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
@@ -33,6 +43,10 @@ type ImageInstance struct {
 	metav1.TypeMeta   `json:",inline"`
 	metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
 
+	// Remote indicates that this image has not been locally cached to the internal registry
+	// meaning that it may not exist at the location recorded in the Repo field if the user
+	// has deleted the image after the fact
+	Remote bool     `json:"remote,omitempty"`
 	Repo   string   `json:"repo,omitempty"`
 	Digest string   `json:"digest,omitempty"`
 	Tags   []string `json:"tags,omitempty"`
