@@ -22,8 +22,17 @@ func AddToScheme(scheme *runtime.Scheme) error {
 		&BuilderInstanceList{},
 		&AppInstance{},
 		&AppInstanceList{},
+		&ServiceInstance{},
+		&ServiceInstanceList{},
 		&ImageInstance{},
-		&ImageInstanceList{})
+		&ImageInstanceList{},
+		&ImageAllowRuleInstance{},
+		&ImageAllowRuleInstanceList{},
+		&EventInstance{},
+		&EventInstanceList{},
+		&DevSessionInstance{},
+		&DevSessionInstanceList{},
+	)
 
 	// Add common types
 	scheme.AddKnownTypes(SchemeGroupVersion, &metav1.Status{})
