@@ -9,6 +9,7 @@ import (
 
 	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
+	"github.com/acorn-io/acorn/pkg/imageallowrules"
 	kclient "github.com/acorn-io/acorn/pkg/k8sclient"
 	"github.com/acorn-io/baaah/pkg/router"
 	"github.com/acorn-io/baaah/pkg/typed"
@@ -16,6 +17,7 @@ import (
 	"github.com/google/go-containerregistry/pkg/v1/remote"
 	"github.com/stretchr/testify/assert"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/utils/strings/slices"
 )
 
 type mockDaemonClient struct {
@@ -25,6 +27,7 @@ type mockDaemonClient struct {
 	localTags, remoteTags               []string
 	remoteImageDigest, resolvedLocalTag string
 	localTagFound                       bool
+	imageDenyList                       map[string]struct{}
 }
 
 func (m *mockDaemonClient) getConfig(_ context.Context) (*apiv1.Config, error) {
@@ -56,13 +59,23 @@ func (m *mockDaemonClient) imageDigest(_ context.Context, namespace, name string
 	if m.remoteImageDigest != "" {
 		return m.remoteImageDigest, nil
 	}
-	return fmt.Sprintf("sha256:%s1234%sabcd", namespace, name), nil
+	if slices.Contains(m.remoteTags, name) {
+		return fmt.Sprintf("sha256:%s1234%sabcd", namespace, name), nil
+	}
+	return "", nil
 }
 
 func (m *mockDaemonClient) resolveLocalTag(context.Context, string, string) (string, bool, error) {
 	return m.resolvedLocalTag, m.localTagFound, nil
 }
 
+func (m *mockDaemonClient) checkImageAllowed(_ context.Context, _ string, img string) error {
+	if _, ok := m.imageDenyList[img]; ok {
+		return &imageallowrules.ErrImageNotAllowed{Image: img}
+	}
+	return nil
+}
+
 func TestDetermineAppsToRefresh(t *testing.T) {
 	defaultNextCheckInterval := time.Minute
 	now := time.Now()
@@ -177,10 +190,15 @@ func TestRefreshImages(t *testing.T) {
 	thirtySecondsAgo := now.Add(-30 * time.Second)
 	ptrTrue := &[]bool{true}[0]
 	appImages := map[string]string{
-		"test-1":      "acorn/test-1:v#.#.#",
-		"acorn-1":     "docker.io/acorn/acorn-1:v1.1.1-*",
-		"enabled-app": "docker.io/acorn/enabled:latest",
-		"notify-app":  "docker.io/acorn/notify:latest",
+		"test-1":               "acorn/test-1:v#.#.#",
+		"acorn-1":              "docker.io/acorn/acorn-1:v1.1.1-*",
+		"enabled-app":          "docker.io/acorn/enabled:latest",
+		"notify-app":           "docker.io/acorn/notify:latest",
+		"no-tag-app":           "docker.io/acorn/no-tag",
+		"test-autoupgrade":     "index.docker.io/acorn/test-autoupgrade:v#.#.#",
+		"test-single-app":      "test-single:*",
+		"test-double-app":      "test-double:**",
+		"test-hash-double-app": "test-hash-double:v#.#.#**",
 	}
 	apps := make(map[kclient.ObjectKey]v1.AppInstance, len(appImages))
 	for _, entry := range typed.Sorted(appImages) {
@@ -190,7 +208,7 @@ func TestRefreshImages(t *testing.T) {
 			Status:     v1.AppInstanceStatus{AppImage: v1.AppImage{Digest: fmt.Sprintf("sha256:acorn1234%sabcd", strings.Split(entry.Value, ":")[0])}},
 		}
 		switch entry.Key {
-		case "enabled-app":
+		case "enabled-app", "no-tag-app":
 			app.Spec.AutoUpgrade = ptrTrue
 		case "notify-app":
 			app.Spec.NotifyUpgrade = ptrTrue
@@ -268,18 +286,34 @@ func TestRefreshImages(t *testing.T) {
 			name:                   "Auto refresh tag with remote digest change",
 			client:                 &mockDaemonClient{remoteImageDigest: "sha256:acorn4321docker.io/acorn/acorn-1dcba"},
 			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "acorn-1"): thirtySecondsAgo},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "docker.io/acorn/acorn-1:tag", namespace: "acorn"}: {router.Key("acorn", "acorn-1")}},
+			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "acorn-1"): now},
+			appsUpdated:            map[string]string{"acorn-1": "docker.io/acorn/acorn-1:tag"},
+		},
+		{
+			name:                   "Auto refresh tag with remote digest change but new image is disallowed", // Note: this is not 100% accurate, since imageAllowRules check against image digests, but it's good enough to test the logic
+			client:                 &mockDaemonClient{remoteImageDigest: "sha256:acorn4321docker.io/acorn/acorn-1dcba", imageDenyList: map[string]struct{}{"docker.io/acorn/acorn-1": {}}},
+			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "acorn-1"): thirtySecondsAgo},
 			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "docker.io/acorn/acorn-1", namespace: "acorn"}: {router.Key("acorn", "acorn-1")}},
 			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "acorn-1"): now},
-			appsUpdated:            map[string]string{"acorn-1": "docker.io/acorn/acorn-1"},
 		},
 		{
 			name:                   "Auto refresh tag with local digest change",
 			client:                 &mockDaemonClient{resolvedLocalTag: "sha256:acorn4321docker.io/acorn/acorn-1dcba", localTagFound: true},
 			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "acorn-1"): thirtySecondsAgo},
-			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "docker.io/acorn/acorn-1", namespace: "acorn"}: {router.Key("acorn", "acorn-1")}},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "docker.io/acorn/acorn-1:tag", namespace: "acorn"}: {router.Key("acorn", "acorn-1")}},
 			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "acorn-1"): now},
-			appsUpdated:            map[string]string{"acorn-1": "docker.io/acorn/acorn-1"},
+			appsUpdated:            map[string]string{"acorn-1": "docker.io/acorn/acorn-1:tag"},
 		},
+
+		{
+			name:                   "Auto refresh tag with remote digest unchanged and local digest changed, remote wins, no update",
+			client:                 &mockDaemonClient{remoteTags: []string{"docker.io/acorn/test-1:v1.0.0"}, remoteImageDigest: "sha256:acorn1234acorn/test-1abcd", resolvedLocalTag: "sha256:acorn4321docker.io/acorn/test-1dcba", localTagFound: true},
+			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-1"): thirtySecondsAgo},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "docker.io/acorn/test-1:v1.0.0", namespace: "acorn"}: {router.Key("acorn", "test-1")}},
+			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-1"): now},
+		},
+
 		{
 			name:                   "Auto refresh tag with no local digest found",
 			client:                 &mockDaemonClient{resolvedLocalTag: "sha256:acorn4321docker.io/acorn/acorn-1dcba"},
@@ -297,7 +331,7 @@ func TestRefreshImages(t *testing.T) {
 		},
 		{
 			name:                   "Auto refresh enabled with no local digest change",
-			client:                 &mockDaemonClient{localTagFound: true},
+			client:                 &mockDaemonClient{localTagFound: true, remoteTags: []string{"docker.io/acorn/enabled"}},
 			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "enabled-app"): thirtySecondsAgo},
 			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "docker.io/acorn/enabled", namespace: "acorn"}: {router.Key("acorn", "enabled-app")}},
 			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "enabled-app"): now},
@@ -320,7 +354,7 @@ func TestRefreshImages(t *testing.T) {
 		},
 		{
 			name:                   "Auto refresh notify with no local digest change",
-			client:                 &mockDaemonClient{localTagFound: true},
+			client:                 &mockDaemonClient{localTagFound: true, remoteTags: []string{"docker.io/acorn/notify"}},
 			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "notify-app"): thirtySecondsAgo},
 			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "docker.io/acorn/notify", namespace: "acorn"}: {router.Key("acorn", "notify-app")}},
 			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "notify-app"): now},
@@ -333,6 +367,67 @@ func TestRefreshImages(t *testing.T) {
 			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "notify-app"): now},
 			appsUpdated:            map[string]string{"notify-app": "docker.io/acorn/notify"},
 		},
+		{
+			name:                   "Auto refresh tag with multiple remote tags with latest tag image denied and current being an older image",
+			client:                 &mockDaemonClient{remoteImageDigest: "sha256:acorn1234index.docker.io/acorn/test-autoupgradeabcd", remoteTags: []string{"v1.1.1", "v1.1.2"}, imageDenyList: map[string]struct{}{"index.docker.io/acorn/test-autoupgrade:v1.1.2": {}}},
+			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-autoupgrade"): thirtySecondsAgo},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "index.docker.io/acorn/test-autoupgrade:v1.1.1", namespace: "acorn"}: {router.Key("acorn", "test-autoupgrade")}},
+			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-autoupgrade"): now},
+		},
+		{
+			name:                   "Auto refresh tag with multiple remote tags with latest tag image denied and current being latest image",
+			client:                 &mockDaemonClient{remoteImageDigest: "sha256:acorn1234index.docker.io/acorn/test-autoupgradeabcd", remoteTags: []string{"v1.1.1", "v1.1.2"}, imageDenyList: map[string]struct{}{"index.docker.io/acorn/test-autoupgrade:v1.1.2": {}}},
+			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-autoupgrade"): thirtySecondsAgo},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "index.docker.io/acorn/test-autoupgrade:v1.1.2", namespace: "acorn"}: {router.Key("acorn", "test-autoupgrade")}},
+			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-autoupgrade"): now},
+		},
+		{
+			name:                   "Auto refresh tag with multiple remote tags with non-latest tag image denied and current being the oldest image",
+			client:                 &mockDaemonClient{remoteTags: []string{"v1.1.1", "v1.1.2", "v1.1.3"}, imageDenyList: map[string]struct{}{"index.docker.io/acorn/test-autoupgrade:v1.1.2": {}}},
+			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-autoupgrade"): thirtySecondsAgo},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "index.docker.io/acorn/test-autoupgrade", namespace: "acorn"}: {router.Key("acorn", "test-autoupgrade")}},
+			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-autoupgrade"): now},
+			appsUpdated:            map[string]string{"test-autoupgrade": "index.docker.io/acorn/test-autoupgrade:v1.1.3"},
+		},
+		{
+			name:                   "No tag auto refresh with remote digest change, no local",
+			client:                 &mockDaemonClient{remoteImageDigest: "sha256:no-tag-updated-digest", remoteTags: []string{"latest", "zeta", "alpha", "beta"}},
+			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "no-tag-app"): thirtySecondsAgo},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "docker.io/acorn/no-tag", namespace: "acorn"}: {router.Key("acorn", "no-tag-app")}},
+			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "no-tag-app"): now},
+			appsUpdated:            map[string]string{"no-tag-app": "docker.io/acorn/no-tag"},
+		},
+		{
+			name:                   "Auto refresh tag containing only '*' with multiple local tags",
+			client:                 &mockDaemonClient{localTags: []string{"alpha", "beta"}},
+			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-single-app"): thirtySecondsAgo},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "test-single", namespace: "acorn"}: {router.Key("acorn", "test-single-app")}},
+			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-single-app"): now},
+			appsUpdated:            map[string]string{"test-single-app": "test-single:beta"},
+		},
+		{
+			name:                   "Auto refresh tag containing only '**' with multiple local tags",
+			client:                 &mockDaemonClient{localTags: []string{"alpha", "beta"}},
+			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-double-app"): thirtySecondsAgo},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "test-double", namespace: "acorn"}: {router.Key("acorn", "test-double-app")}},
+			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-double-app"): now},
+			appsUpdated:            map[string]string{"test-double-app": "test-double:alpha"},
+		},
+		{
+			name:                   "Auto refresh tag combining '#' and '**' with multiple local tags",
+			client:                 &mockDaemonClient{localTags: []string{"v0.0.1-rc1", "v0.0.2"}},
+			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-hash-double-app"): thirtySecondsAgo},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "test-hash-double", namespace: "acorn"}: {router.Key("acorn", "test-hash-double-app")}},
+			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-hash-double-app"): now},
+			appsUpdated:            map[string]string{"test-hash-double-app": "test-hash-double:v0.0.2"},
+		},
+		{
+			name:                   "Auto refresh tag with no match and remote tags should not be updated if image tag not set",
+			client:                 &mockDaemonClient{remoteTags: []string{"v1.1", "v1.2", "latest"}, remoteImageDigest: "sha256:remote-digest"},
+			appKeysPrevCheckBefore: map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-autoupgrade"): thirtySecondsAgo},
+			imagesToRefresh:        map[imageAndNamespaceKey][]kclient.ObjectKey{{image: "index.docker.io/acorn/test-autoupgrade", namespace: "acorn"}: {router.Key("acorn", "test-autoupgrade")}},
+			appKeysPrevCheckAfter:  map[kclient.ObjectKey]time.Time{router.Key("acorn", "test-autoupgrade"): now},
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
