@@ -126,7 +126,7 @@ func (s *Server) build(ctx context.Context, messages buildclient.Messages, token
 	if err != nil {
 		return nil, err
 	}
-	image, err := build.Build(ctx, messages, token.PushRepo, &token.Build.Spec, keychain)
+	image, err := build.Build(ctx, messages, token.PushRepo, token.Build.Spec, keychain)
 	if err != nil {
 		_ = s.recordBuildError(ctx, &token.Build, err)
 		return nil, err
@@ -173,20 +173,32 @@ func (s *Server) recordBuild(ctx context.Context, recordRepo string, build *v1.A
 	if imagesystem.IsClusterInternalRegistryAddressReference(recordRepo) {
 		recordRepo = ""
 	}
-	err := apply.New(s.client).Ensure(ctx, &v1.ImageInstance{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      image.ID,
-			Namespace: build.Namespace,
-		},
-		Repo:   recordRepo,
-		Digest: image.Digest,
-	})
-	if err != nil {
+
+	imageInst := new(v1.ImageInstance)
+	if err := s.client.Get(ctx, kclient.ObjectKey{Name: image.ID, Namespace: build.Namespace}, imageInst); err == nil && imageInst.Remote {
+		// Ensure that the image is not remote since  it was built locally.
+		// This can happen if an image was pulled from a remote registry and then built locally.
+		imageInst.Remote = false
+		if err = s.client.Update(ctx, imageInst); err != nil {
+			return err
+		}
+	} else if apierrors.IsNotFound(err) {
+		if err = apply.New(s.client).Ensure(ctx, &v1.ImageInstance{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      image.ID,
+				Namespace: build.Namespace,
+			},
+			Repo:   recordRepo,
+			Digest: image.Digest,
+		}); err != nil {
+			return err
+		}
+	} else if err != nil {
 		return err
 	}
 
 	recordedBuild := &v1.AcornImageBuildInstance{}
-	err = s.client.Get(ctx, kclient.ObjectKeyFromObject(build), recordedBuild)
+	err := s.client.Get(ctx, kclient.ObjectKeyFromObject(build), recordedBuild)
 	if apierrors.IsNotFound(err) {
 		return nil
 	} else if err != nil {
