@@ -3,17 +3,13 @@ package cli
 import (
 	"fmt"
 
-	"github.com/acorn-io/acorn/pkg/build"
 	cli "github.com/acorn-io/acorn/pkg/cli/builder"
 	"github.com/acorn-io/acorn/pkg/client"
-	"github.com/acorn-io/acorn/pkg/config"
-	"github.com/acorn-io/acorn/pkg/credentials"
+	"github.com/acorn-io/acorn/pkg/imagesource"
 	"github.com/acorn-io/acorn/pkg/progressbar"
-	"github.com/acorn-io/acorn/pkg/streams"
 	"github.com/google/go-containerregistry/pkg/name"
 	"github.com/rancher/wrangler/pkg/merr"
 	"github.com/spf13/cobra"
-	"github.com/spf13/pflag"
 )
 
 func NewBuild(c CommandContext) *cobra.Command {
@@ -33,7 +29,7 @@ acorn build .`,
 
 type Build struct {
 	Push     bool     `usage:"Push image after build"`
-	File     string   `short:"f" usage:"Name of the build file" default:"DIRECTORY/Acornfile"`
+	File     string   `short:"f" usage:"Name of the build file (default \"DIRECTORY/Acornfile\")"`
 	Tag      []string `short:"t" usage:"Apply a tag to the final build"`
 	Platform []string `short:"p" usage:"Target platforms (form os/arch[/variant][:osversion] example linux/amd64)"`
 	Profile  []string `usage:"Profile to assign default values"`
@@ -49,45 +45,15 @@ func (s *Build) Run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	cfg, err := config.ReadCLIConfig()
-	if err != nil {
-		return err
-	}
-
-	creds, err := credentials.NewStore(cfg, c)
-	if err != nil {
-		return err
-	}
-
-	cwd := args[0]
-
-	params, err := build.ParseParams(s.File, cwd, args)
-	if err == pflag.ErrHelp {
-		return nil
-	} else if err != nil {
-		return err
-	}
-
-	platforms, err := build.ParsePlatforms(s.Platform)
-	if err != nil {
-		return err
-	}
-
-	image, err := c.AcornImageBuild(cmd.Context(), s.File, &client.AcornImageBuildOptions{
-		Credentials: creds.Get,
-		Cwd:         cwd,
-		Platforms:   platforms,
-		Args:        params,
-		Profiles:    s.Profile,
-		Streams:     &streams.Current().Output,
-	})
+	helper := imagesource.NewImageSource(s.File, args, s.Profile, s.Platform)
+	image, _, err := helper.GetImageAndDeployArgs(cmd.Context(), c)
 	if err != nil {
 		return err
 	}
 
 	var errs []error
 	for _, tag := range s.Tag {
-		if err = c.ImageTag(cmd.Context(), image.ID, tag); err != nil {
+		if err = c.ImageTag(cmd.Context(), image, tag); err != nil {
 			errs = append(errs, err)
 		}
 	}
@@ -96,7 +62,7 @@ func (s *Build) Run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	fmt.Println(image.ID)
+	fmt.Println(image)
 
 	if s.Push {
 		for _, tag := range s.Tag {
@@ -104,7 +70,11 @@ func (s *Build) Run(cmd *cobra.Command, args []string) error {
 			if err != nil {
 				return err
 			}
-			auth, _, err := creds.Get(cmd.Context(), parsedTag.RegistryStr())
+			creds, err := imagesource.GetCreds(c)
+			if err != nil {
+				return err
+			}
+			auth, _, err := creds(cmd.Context(), parsedTag.RegistryStr())
 			if err != nil {
 				return err
 			}
