@@ -112,12 +112,7 @@ func appsCompletion(ctx context.Context, c client.Client, toComplete string) ([]
 
 func containersCompletion(ctx context.Context, c client.Client, toComplete string) ([]string, error) {
 	var result []string
-	var opts *client.ContainerReplicaListOptions
-	if strings.Contains(toComplete, ".") {
-		opts = &client.ContainerReplicaListOptions{App: strings.Split(toComplete, ".")[0]}
-	}
-
-	containers, err := c.ContainerReplicaList(ctx, opts)
+	containers, err := c.ContainerReplicaList(ctx, nil)
 	if err != nil {
 		return nil, err
 	}
@@ -206,7 +201,6 @@ func imagesCompletion(allowDigest bool) completionFunc {
 					result = append(result, digest)
 				}
 			}
-
 		}
 
 		return result, nil
@@ -360,3 +354,19 @@ func computeClassFlagCompletion(ctx context.Context, c client.Client, toComplete
 
 	return result, err
 }
+
+func regionsCompletion(ctx context.Context, c client.Client, toComplete string) ([]string, error) {
+	regions, err := c.RegionList(ctx)
+	if err != nil {
+		return nil, err
+	}
+
+	var result []string
+	for _, region := range regions {
+		if strings.HasPrefix(region.Name, toComplete) {
+			result = append(result, region.Name)
+		}
+	}
+
+	return result, nil
+}
