@@ -1158,3 +1158,63 @@ func TestComputeClassFlagCompletion(t *testing.T) {
 		})
 	}
 }
+
+func TestProjectRegionFlagCompletion(t *testing.T) {
+	names := []string{"default", "foo", "bar", "baz", "zap"}
+	regions := make([]apiv1.Region, 0, len(names))
+	for _, name := range names {
+		regions = append(regions, apiv1.Region{ObjectMeta: metav1.ObjectMeta{Name: name}})
+	}
+	mockClientFactory := &testdata.MockClientFactory{
+		RegionList: regions,
+	}
+	cmd := new(cobra.Command)
+	cmd.SetContext(context.Background())
+
+	tests := []struct {
+		name          string
+		args          []string
+		toComplete    string
+		wantNames     []string
+		wantDirective cobra.ShellCompDirective
+	}{
+		{
+			name:          "Complete region",
+			wantNames:     names,
+			wantDirective: cobra.ShellCompDirectiveNoFileComp,
+		},
+		{
+			name:          "Complete region staring with b",
+			toComplete:    "b",
+			wantNames:     []string{"bar", "baz"},
+			wantDirective: cobra.ShellCompDirectiveNoFileComp,
+		},
+		{
+			name:          "Complete bar, only test returned",
+			toComplete:    "bar",
+			wantNames:     []string{"bar"},
+			wantDirective: cobra.ShellCompDirectiveNoFileComp,
+		},
+		{
+			name:          "Complete empty, but all names already in args",
+			args:          names,
+			wantNames:     []string{},
+			wantDirective: cobra.ShellCompDirectiveNoFileComp,
+		},
+		{
+			name:          "Complete something that doesn't exist",
+			toComplete:    "hello",
+			wantNames:     nil,
+			wantDirective: cobra.ShellCompDirectiveNoFileComp,
+		},
+	}
+
+	comp := newCompletion(mockClientFactory, regionsCompletion)
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			got, got1 := comp.complete(cmd, tt.args, tt.toComplete)
+			assert.Equalf(t, tt.wantNames, got, "regoinCompletion(_, _, %v, %v)", tt.args, tt.toComplete)
+			assert.Equalf(t, tt.wantDirective, got1, "regoinCompletion(_, _, %v, %v)", tt.args, tt.toComplete)
+		})
+	}
+}
