@@ -7,7 +7,7 @@ import (
 
 	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
 	cli "github.com/acorn-io/acorn/pkg/cli/builder"
-	"github.com/acorn-io/acorn/pkg/cue"
+	"github.com/acorn-io/aml/pkg/cue"
 	"github.com/spf13/cobra"
 )
 
