@@ -4,33 +4,34 @@ import (
 	"fmt"
 
 	cli "github.com/acorn-io/acorn/pkg/cli/builder"
-	"github.com/acorn-io/acorn/pkg/client"
 	"github.com/spf13/cobra"
 )
 
-func NewStart() *cobra.Command {
-	return cli.Command(&Start{}, cobra.Command{
+func NewStart(c CommandContext) *cobra.Command {
+	return cli.Command(&Start{client: c.ClientFactory}, cobra.Command{
 		Use: "start [flags] [APP_NAME...]",
 		Example: `
 acorn start my-app
 
 acorn start my-app1 my-app2`,
-		SilenceUsage: true,
-		Short:        "Start an app",
+		SilenceUsage:      true,
+		Short:             "Start an app",
+		ValidArgsFunction: newCompletion(c.ClientFactory, appsCompletion).complete,
 	})
 }
 
 type Start struct {
+	client ClientFactory
 }
 
 func (a *Start) Run(cmd *cobra.Command, args []string) error {
-	client, err := client.Default()
+	c, err := a.client.CreateDefault()
 	if err != nil {
 		return err
 	}
 
 	for _, arg := range args {
-		err := client.AppStart(cmd.Context(), arg)
+		err := c.AppStart(cmd.Context(), arg)
 		if err != nil {
 			return fmt.Errorf("starting %s: %w", arg, err)
 		}
