@@ -5,6 +5,8 @@ import (
 	"fmt"
 	"net"
 
+	"github.com/acorn-io/acorn/pkg/labels"
+
 	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/client"
@@ -47,6 +49,10 @@ type MockClientFactory struct {
 	VolumeClassItem  *apiv1.VolumeClass
 	ComputeClassList []apiv1.ComputeClass
 	ComputeClassItem *apiv1.ComputeClass
+	RegionList       []apiv1.Region
+	RegionItem       *apiv1.Region
+	EventList        []apiv1.Event
+	EventItem        *apiv1.Event
 }
 
 func (dc *MockClientFactory) Options() project.Options {
@@ -73,6 +79,10 @@ func (dc *MockClientFactory) CreateDefault() (client.Client, error) {
 		VolumeClassItem:  dc.VolumeClassItem,
 		ComputeClasses:   dc.ComputeClassList,
 		ComputeClassItem: dc.ComputeClassItem,
+		Regions:          dc.RegionList,
+		RegionItem:       dc.RegionItem,
+		Events:           dc.EventList,
+		EventItem:        dc.EventItem,
 	}, nil
 }
 
@@ -95,6 +105,20 @@ type MockClient struct {
 	VolumeClassItem  *apiv1.VolumeClass
 	ComputeClasses   []apiv1.ComputeClass
 	ComputeClassItem *apiv1.ComputeClass
+	Regions          []apiv1.Region
+	RegionItem       *apiv1.Region
+	Events           []apiv1.Event
+	EventItem        *apiv1.Event
+}
+
+func (m *MockClient) DevSessionRenew(ctx context.Context, name string, client v1.DevSessionInstanceClient) error {
+	//TODO implement me
+	panic("implement me")
+}
+
+func (m *MockClient) DevSessionRelease(ctx context.Context, name string) error {
+	//TODO implement me
+	panic("implement me")
 }
 
 func (m *MockClient) AppPullImage(ctx context.Context, name string) error {
@@ -440,15 +464,27 @@ func (m *MockClient) ContainerReplicaExec(ctx context.Context, name string, args
 	return nil, nil
 }
 
+func (m *MockClient) ContainerReplicaPortForward(ctx context.Context, name string, port int) (client.PortForwardDialer, error) {
+	return nil, nil
+}
+
 func (m *MockClient) VolumeList(ctx context.Context) ([]apiv1.Volume, error) {
 	if m.Volumes != nil {
 		return m.Volumes, nil
 	}
 	return []apiv1.Volume{{
-		TypeMeta:   metav1.TypeMeta{},
-		ObjectMeta: metav1.ObjectMeta{Name: "found.volume"},
-		Spec:       apiv1.VolumeSpec{},
-		Status:     apiv1.VolumeStatus{AppName: "found", VolumeName: "found.volume"},
+		TypeMeta: metav1.TypeMeta{},
+		ObjectMeta: metav1.ObjectMeta{Name: "found.vol",
+			Labels: map[string]string{
+				labels.AcornVolumeName: "vol",
+				labels.AcornAppName:    "found",
+			}},
+		Spec: apiv1.VolumeSpec{},
+		Status: apiv1.VolumeStatus{
+			AppPublicName: "found",
+			AppName:       "found",
+			VolumeName:    "vol",
+		},
 	}}, nil
 }
 
@@ -456,15 +492,27 @@ func (m *MockClient) VolumeGet(ctx context.Context, name string) (*apiv1.Volume,
 	if m.VolumeItem != nil {
 		return m.VolumeItem, nil
 	}
+	potentialVol := apiv1.Volume{TypeMeta: metav1.TypeMeta{},
+		ObjectMeta: metav1.ObjectMeta{Name: "found.vol",
+			Labels: map[string]string{
+				labels.AcornVolumeName: "vol",
+				labels.AcornAppName:    "found",
+			}},
+		Spec: apiv1.VolumeSpec{},
+		Status: apiv1.VolumeStatus{
+			AppName:       "found",
+			AppPublicName: "found",
+			VolumeName:    "vol",
+		},
+	}
+
 	switch name {
 	case "dne":
 		return nil, fmt.Errorf("error: volume %s does not exist", name)
-	case "found.volume":
-		return &apiv1.Volume{TypeMeta: metav1.TypeMeta{},
-			ObjectMeta: metav1.ObjectMeta{Name: "found.volume"},
-			Spec:       apiv1.VolumeSpec{},
-			Status:     apiv1.VolumeStatus{AppName: "found", VolumeName: "found.volume"},
-		}, nil
+	case "volume":
+		return &potentialVol, nil
+	case "found.vol":
+		return &potentialVol, nil
 	}
 	return nil, nil
 }
@@ -476,7 +524,9 @@ func (m *MockClient) VolumeDelete(ctx context.Context, name string) (*apiv1.Volu
 	switch name {
 	case "dne":
 		return nil, nil
-	case "found.volume":
+	case "volume":
+		return &apiv1.Volume{}, nil
+	case "found.vol":
 		return &apiv1.Volume{}, nil
 	}
 	return nil, nil
@@ -507,25 +557,36 @@ func (m *MockClient) ImageGet(ctx context.Context, name string) (*apiv1.Image, e
 	if m.ImageItem != nil {
 		return m.ImageItem, nil
 	}
-	return nil, nil
+	return &apiv1.Image{
+		TypeMeta:   metav1.TypeMeta{},
+		ObjectMeta: metav1.ObjectMeta{Name: "found-image1234567"},
+		Tags:       []string{"testtag:latest"},
+		Digest:     "1234567890asdfghkl",
+	}, nil
 }
 
-func (m *MockClient) ImageDelete(ctx context.Context, name string, opts *client.ImageDeleteOptions) (*apiv1.Image, error) {
+func (m *MockClient) ImageDelete(ctx context.Context, name string, opts *client.ImageDeleteOptions) (*apiv1.Image, []string, error) {
 	if m.ImageItem != nil {
-		return m.ImageItem, nil
+		return m.ImageItem, m.ImageItem.Tags, nil
 	}
+
+	img := &apiv1.Image{TypeMeta: metav1.TypeMeta{},
+		ObjectMeta: metav1.ObjectMeta{Name: "ff12345"},
+		Tags:       []string{"testtag1:latest", "testtag2:latest", "foo:v1", "foo:v2"},
+	}
+
 	switch name {
-	case "found-image-two-tags1234567":
+	case "ff12345":
 		if !opts.Force {
-			return nil, fmt.Errorf("unable to delete %s (must be forced) - image is referenced in multiple repositories", name)
+			return nil, nil, fmt.Errorf("unable to delete %s (must be forced) - image is referenced in multiple repositories", name)
 		} else {
-			return &apiv1.Image{TypeMeta: metav1.TypeMeta{},
-				ObjectMeta: metav1.ObjectMeta{Name: "found-image-two-tags1234567"},
-				Tags:       []string{"testtag1:latest", "testtag2:latest"},
-			}, nil
+
+			return img, img.Tags, nil
 		}
+	case "foo:v1": // just remove a tag
+		return nil, []string{"foo:v1"}, nil
 	}
-	return nil, nil
+	return nil, nil, apierrors.NewNotFound(schema.GroupResource{Group: "acorn", Resource: "images"}, name)
 }
 
 func (m *MockClient) ImagePush(ctx context.Context, tagName string, opts *client.ImagePushOptions) (<-chan client.ImageProgress, error) {
@@ -608,7 +669,6 @@ func (m *MockClient) Info(ctx context.Context) ([]apiv1.Info, error) {
 		{
 			TypeMeta:   metav1.TypeMeta{},
 			ObjectMeta: metav1.ObjectMeta{},
-			Spec:       apiv1.InfoSpec{},
 		},
 	}, nil
 }
@@ -690,7 +750,7 @@ func (m *MockClient) ProjectGet(ctx context.Context, name string) (*apiv1.Projec
 	return nil, nil
 }
 
-func (m *MockClient) ProjectCreate(ctx context.Context, name string) (*apiv1.Project, error) {
+func (m *MockClient) ProjectCreate(ctx context.Context, name string, region string, supportedRegions []string) (*apiv1.Project, error) {
 	// TODO implement me
 	panic("implement me")
 }
@@ -700,6 +760,11 @@ func (m *MockClient) ProjectDelete(ctx context.Context, name string) (*apiv1.Pro
 	panic("implement me")
 }
 
+func (m *MockClient) ProjectUpdate(ctx context.Context, project *apiv1.Project, defaultRegion string, supportedRegions []string) (*apiv1.Project, error) {
+	// TODO implement me
+	panic("implement me")
+}
+
 func (m *MockClient) VolumeClassList(context.Context) ([]apiv1.VolumeClass, error) {
 	return m.VolumeClasses, nil
 }
@@ -720,3 +785,29 @@ func (m *MockClient) VolumeClassGet(_ context.Context, name string) (*apiv1.Volu
 		Resource: "volumeclasses",
 	}, name)
 }
+
+func (m *MockClient) RegionList(context.Context) ([]apiv1.Region, error) {
+	return m.Regions, nil
+}
+
+func (m *MockClient) RegionGet(_ context.Context, name string) (*apiv1.Region, error) {
+	if m.RegionItem != nil {
+		return m.RegionItem, nil
+	}
+
+	for _, s := range m.Regions {
+		if s.Name == name {
+			return &s, nil
+		}
+	}
+
+	return nil, apierrors.NewNotFound(schema.GroupResource{
+		Group:    "api.acorn.io",
+		Resource: "regions",
+	}, name)
+}
+
+func (m *MockClient) EventStream(context.Context, *client.EventStreamOptions) (<-chan apiv1.Event, error) {
+	// TODO: Implement me
+	return nil, nil
+}
