@@ -8,6 +8,8 @@ import (
 	apiv1 "github.com/acorn-io/acorn/pkg/apis/api.acorn.io/v1"
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/client/term"
+	"github.com/sirupsen/logrus"
+	"golang.org/x/sync/errgroup"
 	kclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
@@ -207,6 +209,20 @@ func (m *MultiClient) AppPullImage(ctx context.Context, name string) error {
 	return err
 }
 
+func (m *MultiClient) DevSessionRenew(ctx context.Context, name string, client v1.DevSessionInstanceClient) error {
+	_, err := onOne(ctx, m.Factory, name, func(name string, c Client) (*apiv1.App, error) {
+		return &apiv1.App{}, c.DevSessionRenew(ctx, name, client)
+	})
+	return err
+}
+
+func (m *MultiClient) DevSessionRelease(ctx context.Context, name string) error {
+	_, err := onOne(ctx, m.Factory, name, func(name string, c Client) (*apiv1.App, error) {
+		return &apiv1.App{}, c.DevSessionRelease(ctx, name)
+	})
+	return err
+}
+
 func (m *MultiClient) CredentialCreate(ctx context.Context, serverAddress, username, password string, skipChecks bool) (*apiv1.Credential, error) {
 	return onOne(ctx, m.Factory, serverAddress, func(name string, c Client) (*apiv1.Credential, error) {
 		return c.CredentialCreate(ctx, name, username, password, skipChecks)
@@ -305,6 +321,14 @@ func (m *MultiClient) ContainerReplicaExec(ctx context.Context, name string, arg
 	return exec, err
 }
 
+func (m *MultiClient) ContainerReplicaPortForward(ctx context.Context, name string, port int) (dialer PortForwardDialer, err error) {
+	_, err = onOne(ctx, m.Factory, name, func(name string, c Client) (*apiv1.ContainerReplica, error) {
+		dialer, err = c.ContainerReplicaPortForward(ctx, name, port)
+		return &apiv1.ContainerReplica{}, err
+	})
+	return dialer, err
+}
+
 func (m *MultiClient) VolumeList(ctx context.Context) ([]apiv1.Volume, error) {
 	return aggregate(ctx, m.Factory, func(c Client) ([]apiv1.Volume, error) {
 		return c.VolumeList(ctx)
@@ -339,10 +363,10 @@ func (m *MultiClient) ImageGet(ctx context.Context, name string) (*apiv1.Image,
 	return c.ImageGet(ctx, name)
 }
 
-func (m *MultiClient) ImageDelete(ctx context.Context, name string, opts *ImageDeleteOptions) (*apiv1.Image, error) {
+func (m *MultiClient) ImageDelete(ctx context.Context, name string, opts *ImageDeleteOptions) (*apiv1.Image, []string, error) {
 	c, err := m.Factory.ForProject(ctx, m.Factory.DefaultProject())
 	if err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 	return c.ImageDelete(ctx, name, opts)
 }
@@ -437,12 +461,20 @@ func (m *MultiClient) ProjectDelete(ctx context.Context, name string) (*apiv1.Pr
 	return c.ProjectDelete(ctx, name)
 }
 
-func (m *MultiClient) ProjectCreate(ctx context.Context, name string) (*apiv1.Project, error) {
+func (m *MultiClient) ProjectCreate(ctx context.Context, name, defaultRegion string, supportedRegions []string) (*apiv1.Project, error) {
 	c, err := m.Factory.ForProject(ctx, m.Factory.DefaultProject())
 	if err != nil {
 		return nil, err
 	}
-	return c.ProjectCreate(ctx, name)
+	return c.ProjectCreate(ctx, name, defaultRegion, supportedRegions)
+}
+
+func (m *MultiClient) ProjectUpdate(ctx context.Context, project *apiv1.Project, defaultRegion string, supportedRegions []string) (*apiv1.Project, error) {
+	c, err := m.Factory.ForProject(ctx, m.Factory.DefaultProject())
+	if err != nil {
+		return nil, err
+	}
+	return c.ProjectUpdate(ctx, project, defaultRegion, supportedRegions)
 }
 
 func (m *MultiClient) ProjectList(ctx context.Context) ([]apiv1.Project, error) {
@@ -470,6 +502,18 @@ func (m *MultiClient) ComputeClassList(ctx context.Context) ([]apiv1.ComputeClas
 	})
 }
 
+func (m *MultiClient) RegionGet(ctx context.Context, name string) (*apiv1.Region, error) {
+	return onOne(ctx, m.Factory, name, func(name string, client Client) (*apiv1.Region, error) {
+		return client.RegionGet(ctx, name)
+	})
+}
+
+func (m *MultiClient) RegionList(ctx context.Context) ([]apiv1.Region, error) {
+	return aggregate(ctx, m.Factory, func(client Client) ([]apiv1.Region, error) {
+		return client.RegionList(ctx)
+	})
+}
+
 func (m *MultiClient) Info(ctx context.Context) ([]apiv1.Info, error) {
 	return aggregateOptionalNaming(ctx, false, m.Factory, func(c Client) ([]apiv1.Info, error) {
 		infos, err := c.Info(ctx)
@@ -483,11 +527,56 @@ func (m *MultiClient) Info(ctx context.Context) ([]apiv1.Info, error) {
 	})
 }
 
+func (m *MultiClient) EventStream(ctx context.Context, opts *EventStreamOptions) (<-chan apiv1.Event, error) {
+	clients, err := m.Factory.List(ctx)
+	if err != nil {
+		return nil, err
+	}
+
+	all := make(chan apiv1.Event)
+	g, gCtx := errgroup.WithContext(ctx)
+	for _, client := range clients {
+		c := client
+		g.Go(func() error {
+			stream, err := c.EventStream(gCtx, opts)
+			if err != nil {
+				return err
+			}
+
+			for e := range stream {
+				select {
+				case <-gCtx.Done():
+					return gCtx.Err()
+				case all <- e:
+				}
+			}
+
+			return nil
+		})
+	}
+	go func() {
+		defer close(all)
+		if err := g.Wait(); err != nil {
+			logrus.Errorf("Error streaming events: %s", err.Error())
+		}
+	}()
+
+	return all, nil
+}
+
 func (m *MultiClient) GetProject() string {
 	return m.project
 }
 
 func (m *MultiClient) GetNamespace() string {
+	if m.namespace == "" {
+		c, err := m.Factory.ForProject(context.Background(), m.Factory.DefaultProject())
+		if err != nil {
+			panic(err)
+		}
+		return c.GetNamespace()
+	}
+
 	return m.namespace
 }
 
