@@ -2,6 +2,7 @@ package term
 
 import (
 	"io"
+	"time"
 
 	"github.com/acorn-io/acorn/pkg/streams"
 	"golang.org/x/sync/errgroup"
@@ -61,7 +62,22 @@ func copyIO(cIO *ExecIO, streams *streams.Streams) <-chan struct{} {
 	result := make(chan struct{})
 
 	go func() {
-		_, _ = io.Copy(cIO.Stdin, streams.In)
+		c, err := io.Copy(cIO.Stdin, streams.In)
+		if c == 0 && err == nil {
+			// Very good chance the stdin was closed at start, so just wait
+			// until stdout/stderr are done
+			<-result
+		} else {
+			// This is an unfortunate hack. It does not seem possible to close the
+			// stdin side of an exec session to kubernetes over a WebSocket. This
+			// means that for a command like "echo hi | acorn exec container cat" we
+			// can not reliably run it. For a command like that you have to finish
+			// reading stdin, close it, and then fully read the response.  If you
+			// don't close stdin, the "cat" command will not exit.  If you do
+			// don't fully read the response you lose the output. So here we just
+			// sleep one second hoping that is enough time to read the output
+			time.Sleep(1 * time.Second)
+		}
 		_ = cIO.Stdin.Close()
 	}()
 
@@ -76,7 +92,7 @@ func copyIO(cIO *ExecIO, streams *streams.Streams) <-chan struct{} {
 	})
 	go func() {
 		_ = eg.Wait()
-		result <- struct{}{}
+		close(result)
 	}()
 
 	return result
