@@ -2,28 +2,28 @@ package appdefinition
 
 import (
 	"crypto/sha256"
-	"encoding/base64"
 	"encoding/hex"
 	"encoding/json"
-	url2 "net/url"
+	"net/url"
 	"path"
 	"strings"
 
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/condition"
 	"github.com/acorn-io/acorn/pkg/config"
-	"github.com/acorn-io/acorn/pkg/expose"
 	"github.com/acorn-io/acorn/pkg/images"
 	"github.com/acorn-io/acorn/pkg/labels"
+	"github.com/acorn-io/acorn/pkg/pdb"
 	"github.com/acorn-io/acorn/pkg/ports"
+	"github.com/acorn-io/acorn/pkg/publicname"
+	"github.com/acorn-io/acorn/pkg/secrets"
 	"github.com/acorn-io/acorn/pkg/system"
-	"github.com/acorn-io/acorn/pkg/tags"
+	"github.com/acorn-io/acorn/pkg/volume"
 	"github.com/acorn-io/baaah/pkg/apply"
 	"github.com/acorn-io/baaah/pkg/router"
 	"github.com/acorn-io/baaah/pkg/typed"
 	"github.com/google/go-containerregistry/pkg/name"
 	"github.com/rancher/wrangler/pkg/data/convert"
-	"golang.org/x/exp/maps"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	apierror "k8s.io/apimachinery/pkg/api/errors"
@@ -51,12 +51,23 @@ func FilterLabelsAndAnnotationsConfig(h router.Handler) router.Handler {
 }
 
 func DeploySpec(req router.Request, resp router.Response) (err error) {
+	// We need this handler to run even when the app is deleting so ensure jobs will clean up
+	if req.Object == nil {
+		return nil
+	}
+
 	appInstance := req.Object.(*v1.AppInstance)
 	status := condition.Setter(appInstance, resp, v1.AppInstanceConditionDefined)
+	interpolator := secrets.NewInterpolator(req.Ctx, req.Client, appInstance)
 
 	defer func() {
 		if err == nil {
-			status.Success()
+			// if there is an issue with interpolation, we just record it on the condition
+			// but still allow the handler to reconcile resp objects. This is to avoid a
+			// possible catch 22 where interpolation fails but we can't update the acorn
+			// because it's failing. This happens when we refer to an object that has
+			// yet to be created
+			status.Error(interpolator.Err())
 		} else {
 			status.Error(err)
 		}
@@ -72,34 +83,30 @@ func DeploySpec(req router.Request, resp router.Response) (err error) {
 		return err
 	}
 
-	if err := addDeployments(req, appInstance, tag, pullSecrets, resp); err != nil {
+	if err := addDeployments(req, appInstance, tag, pullSecrets, interpolator, resp); err != nil {
 		return err
 	}
 	if err := addRouters(appInstance, resp); err != nil {
 		return err
 	}
-	if err := addJobs(req, appInstance, tag, pullSecrets, resp); err != nil {
+	if err := addJobs(req, appInstance, tag, pullSecrets, interpolator, resp); err != nil {
 		return err
 	}
-	if err := addPublish(req, appInstance, resp); err != nil {
-		return err
-	}
-	if err := addExpose(req, appInstance, resp); err != nil {
+	if err := addServices(req, appInstance, resp); err != nil {
 		return err
 	}
 	if err := addPVCs(req, appInstance, resp); err != nil {
 		return err
 	}
-	if err := addConfigMaps(appInstance, resp); err != nil {
-		return err
-	}
+	addAcorns(req, appInstance, tag, pullSecrets, resp)
 
 	resp.Objects(pullSecrets.Objects()...)
+	resp.Objects(interpolator.Objects()...)
 	return pullSecrets.Err()
 }
 
-func addDeployments(req router.Request, appInstance *v1.AppInstance, tag name.Reference, pullSecrets *PullSecrets, resp router.Response) error {
-	deps, err := ToDeployments(req, appInstance, tag, pullSecrets)
+func addDeployments(req router.Request, appInstance *v1.AppInstance, tag name.Reference, pullSecrets *PullSecrets, secrets *secrets.Interpolator, resp router.Response) error {
+	deps, err := ToDeployments(req, appInstance, tag, pullSecrets, secrets)
 	if err != nil {
 		return err
 	}
@@ -123,30 +130,10 @@ func toEnvFrom(envs []v1.EnvVar) (result []corev1.EnvFromSource) {
 	return
 }
 
-func translateEnvValue(app *v1.AppInstance, value string) string {
-	switch value {
-	case "${app.image}":
-		if tags.IsLocalReference(app.Status.AppImage.ID) {
-			return app.Status.AppImage.ID
-		} else if app.Status.AppImage.ID != "" && app.Status.AppImage.Digest != "" {
-			tag, err := name.NewTag(app.Status.AppImage.ID)
-			if err == nil {
-				return tag.Digest(app.Status.AppImage.Digest).String()
-			}
-		}
-	case "${app.namespace}":
-		return app.Namespace
-	}
-	return value
-}
-
-func toEnv(app *v1.AppInstance, envs []v1.EnvVar, appEnv []v1.NameValue) (result []corev1.EnvVar) {
+func toEnv(envs []v1.EnvVar, appEnv []v1.NameValue, interpolator *secrets.Interpolator) (result []corev1.EnvVar) {
 	for _, env := range envs {
 		if env.Secret.Name == "" {
-			result = append(result, corev1.EnvVar{
-				Name:  env.Name,
-				Value: translateEnvValue(app, env.Value),
-			})
+			result = append(result, interpolator.ToEnv(env.Name, env.Value))
 		} else {
 			if env.Secret.Key == "" {
 				continue
@@ -187,13 +174,13 @@ func hasContextDir(container v1.Container) bool {
 	return false
 }
 
-func toContainers(req router.Request, app *v1.AppInstance, tag name.Reference, name string, container v1.Container) ([]corev1.Container, []corev1.Container) {
+func toContainers(app *v1.AppInstance, tag name.Reference, name string, container v1.Container, interpolator *secrets.Interpolator) ([]corev1.Container, []corev1.Container) {
 	var (
 		containers     []corev1.Container
 		initContainers []corev1.Container
 	)
 
-	if app.Spec.GetDevMode() && hasContextDir(container) {
+	if app.Status.GetDevMode() && hasContextDir(container) {
 		initContainers = append(initContainers, corev1.Container{
 			Name:            "acorn-helper",
 			Image:           system.DefaultImage(),
@@ -208,10 +195,10 @@ func toContainers(req router.Request, app *v1.AppInstance, tag name.Reference, n
 		})
 	}
 
-	newContainer := toContainer(req, app, tag, name, name, container)
+	newContainer := toContainer(app, tag, name, container, interpolator)
 	containers = append(containers, newContainer)
 	for _, entry := range typed.Sorted(container.Sidecars) {
-		newContainer = toContainer(req, app, tag, name, entry.Key, entry.Value)
+		newContainer = toContainer(app, tag, entry.Key, entry.Value, interpolator)
 
 		if entry.Value.Init {
 			initContainers = append(initContainers, newContainer)
@@ -236,21 +223,19 @@ func sanitizeVolumeName(name string) string {
 	return name
 }
 
-func toMounts(app *v1.AppInstance, deploymentName, containerName string, container v1.Container) (result []corev1.VolumeMount) {
+func toMounts(app *v1.AppInstance, container v1.Container, interpolation *secrets.Interpolator) (result []corev1.VolumeMount) {
 	for _, entry := range typed.Sorted(container.Files) {
 		suffix := ""
-		if normalizeMode(entry.Value.Mode) != "" {
+		if volume.NormalizeMode(entry.Value.Mode) != "" {
 			suffix = "-" + entry.Value.Mode
 		}
 		if entry.Value.Secret.Key == "" || entry.Value.Secret.Name == "" {
-			result = append(result, corev1.VolumeMount{
-				Name:      "files" + suffix,
-				MountPath: path.Join("/", entry.Key),
-				SubPath:   pathHash(app.Name, deploymentName, containerName, entry.Key),
-			})
+			// inline file
+			result = append(result, interpolation.ToVolumeMount(entry.Key, entry.Value))
 		} else {
+			// file pointing to secret
 			result = append(result, corev1.VolumeMount{
-				Name:      "secret--" + entry.Value.Secret.Name + suffix,
+				Name:      secretPodVolName(entry.Value.Secret.Name + suffix),
 				MountPath: path.Join("/", entry.Key),
 				SubPath:   entry.Value.Secret.Key,
 			})
@@ -261,7 +246,7 @@ func toMounts(app *v1.AppInstance, deploymentName, containerName string, contain
 		mountPath := entry.Key
 		mount := entry.Value
 		if mount.ContextDir != "" {
-			if !helperMounted && app.Spec.GetDevMode() {
+			if !helperMounted && app.Status.GetDevMode() {
 				result = append(result, corev1.VolumeMount{
 					Name:      sanitizeVolumeName(AcornHelper),
 					MountPath: AcornHelperPath,
@@ -276,7 +261,7 @@ func toMounts(app *v1.AppInstance, deploymentName, containerName string, contain
 			})
 		} else {
 			result = append(result, corev1.VolumeMount{
-				Name:      "secret--" + mount.Secret.Name,
+				Name:      secretPodVolName(mount.Secret.Name),
 				MountPath: path.Join("/", mountPath),
 			})
 		}
@@ -314,7 +299,7 @@ func toPorts(container v1.Container) []corev1.ContainerPort {
 }
 
 func parseURLForProbe(probeURL string) (scheme corev1.URIScheme, host string, port intstr.IntOrString, path string, ok bool) {
-	u, err := url2.Parse(probeURL)
+	u, err := url.Parse(probeURL)
 	if err != nil {
 		return
 	}
@@ -388,7 +373,7 @@ func toProbe(container v1.Container, probeType v1.ProbeType) *corev1.Probe {
 	if probeType == v1.ReadinessProbeType &&
 		container.Probes == nil {
 		for _, port := range container.Ports {
-			if port.Protocol == v1.ProtocolUDP {
+			if port.Protocol == v1.ProtocolUDP || port.Dev {
 				continue
 			}
 			return &corev1.Probe{
@@ -404,19 +389,19 @@ func toProbe(container v1.Container, probeType v1.ProbeType) *corev1.Probe {
 	return nil
 }
 
-func toContainer(req router.Request, app *v1.AppInstance, tag name.Reference, deploymentName, containerName string, container v1.Container) corev1.Container {
+func toContainer(app *v1.AppInstance, tag name.Reference, containerName string, container v1.Container, interpolator *secrets.Interpolator) corev1.Container {
 	containerObject := corev1.Container{
 		Name:           containerName,
 		Image:          images.ResolveTag(tag, container.Image),
 		Command:        container.Entrypoint,
 		Args:           container.Command,
 		WorkingDir:     container.WorkingDir,
-		Env:            toEnv(app, container.Environment, app.Spec.Environment),
+		Env:            toEnv(container.Environment, app.Spec.Environment, interpolator),
 		EnvFrom:        toEnvFrom(container.Environment),
 		TTY:            container.Interactive,
 		Stdin:          container.Interactive,
 		Ports:          toPorts(container),
-		VolumeMounts:   toMounts(app, deploymentName, containerName, container),
+		VolumeMounts:   toMounts(app, container, interpolator),
 		LivenessProbe:  toProbe(container, v1.LivenessProbeType),
 		StartupProbe:   toProbe(container, v1.StartupProbeType),
 		ReadinessProbe: toProbe(container, v1.ReadinessProbeType),
@@ -474,12 +459,12 @@ func containerAnnotation(container v1.Container) string {
 	return string(json)
 }
 
-func podAnnotations(appInstance *v1.AppInstance, containerName string, container v1.Container) map[string]string {
+func podAnnotations(appInstance *v1.AppInstance, container v1.Container) map[string]string {
 	annotations := map[string]string{
 		labels.AcornContainerSpec: containerAnnotation(container),
 	}
 	images := map[string]string{}
-	addImageAnnotations(images, appInstance, containerName, container)
+	addImageAnnotations(images, appInstance, container)
 
 	if len(images) == 0 {
 		return annotations
@@ -495,14 +480,13 @@ func podAnnotations(appInstance *v1.AppInstance, containerName string, container
 	return annotations
 }
 
-func addImageAnnotations(annotations map[string]string, appInstance *v1.AppInstance, containerName string, container v1.Container) {
+func addImageAnnotations(annotations map[string]string, appInstance *v1.AppInstance, container v1.Container) {
 	if container.Build != nil && container.Build.BaseImage != "" {
 		annotations[container.Image] = container.Build.BaseImage
 	}
 
 	for _, entry := range typed.Sorted(container.Sidecars) {
-		name, sideCar := entry.Key, entry.Value
-		addImageAnnotations(annotations, appInstance, name, sideCar)
+		addImageAnnotations(annotations, appInstance, entry.Value)
 	}
 }
 
@@ -541,7 +525,7 @@ func getRevision(req router.Request, namespace, secretName string) (string, erro
 	return hex.EncodeToString(d[:]), nil
 }
 
-func getSecretAnnotations(req router.Request, appInstance *v1.AppInstance, container v1.Container) (map[string]string, error) {
+func getSecretAnnotations(req router.Request, appInstance *v1.AppInstance, container v1.Container, interpolator *secrets.Interpolator) (map[string]string, error) {
 	var (
 		secrets []string
 		result  = map[string]string{}
@@ -580,27 +564,28 @@ func getSecretAnnotations(req router.Request, appInstance *v1.AppInstance, conta
 	return result, nil
 }
 
-func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Reference, name string, container v1.Container, pullSecrets *PullSecrets) (*appsv1.Deployment, error) {
+func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Reference, name string, container v1.Container, pullSecrets *PullSecrets, interpolator *secrets.Interpolator) (*appsv1.Deployment, error) {
 	var (
 		stateful = isStateful(appInstance, container)
 	)
 
-	containers, initContainers := toContainers(req, appInstance, tag, name, container)
+	interpolator = interpolator.ForContainer(name)
 
-	secretAnnotations, err := getSecretAnnotations(req, appInstance, container)
+	containers, initContainers := toContainers(appInstance, tag, name, container, interpolator)
+
+	secretAnnotations, err := getSecretAnnotations(req, appInstance, container, interpolator)
 	if err != nil {
 		return nil, err
 	}
 
-	volumes, err := toVolumes(appInstance, container)
+	volumes, err := toVolumes(appInstance, container, interpolator)
 	if err != nil {
 		return nil, err
 	}
 
-	podLabels := containerLabels(appInstance, container, name)
+	podLabels := containerLabels(appInstance, container, name, labels.AcornAppPublicName, publicname.Get(appInstance))
 	deploymentLabels := containerLabels(appInstance, container, name)
 	matchLabels := selectorMatchLabels(appInstance, name)
-	maps.Copy(podLabels, ports.ToPodLabels(appInstance, name))
 
 	deploymentAnnotations := containerAnnotations(appInstance, container, name)
 
@@ -609,7 +594,7 @@ func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Refe
 			Name:        name,
 			Namespace:   appInstance.Status.Namespace,
 			Labels:      deploymentLabels,
-			Annotations: typed.Concat(deploymentAnnotations, getDependencyAnnotations(appInstance, container.Dependencies), secretAnnotations),
+			Annotations: typed.Concat(deploymentAnnotations, getDependencyAnnotations(appInstance, name, container.Dependencies), secretAnnotations),
 		},
 		Spec: appsv1.DeploymentSpec{
 			Replicas: container.Scale,
@@ -619,7 +604,7 @@ func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Refe
 			Template: corev1.PodTemplateSpec{
 				ObjectMeta: metav1.ObjectMeta{
 					Labels:      podLabels,
-					Annotations: typed.Concat(deploymentAnnotations, podAnnotations(appInstance, name, container), secretAnnotations),
+					Annotations: typed.Concat(deploymentAnnotations, podAnnotations(appInstance, container), secretAnnotations),
 				},
 				Spec: corev1.PodSpec{
 					Affinity:                      appInstance.Status.Scheduling[name].Affinity,
@@ -646,96 +631,30 @@ func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Refe
 
 	if appInstance.Spec.Stop != nil && *appInstance.Spec.Stop {
 		dep.Spec.Replicas = new(int32)
+	} else {
+		interpolator.AddMissingAnnotations(dep.Annotations)
 	}
 
 	return dep, nil
 }
 
-func ToDeployments(req router.Request, appInstance *v1.AppInstance, tag name.Reference, pullSecrets *PullSecrets) (result []kclient.Object, _ error) {
+func ToDeployments(req router.Request, appInstance *v1.AppInstance, tag name.Reference, pullSecrets *PullSecrets, secrets *secrets.Interpolator) (result []kclient.Object, _ error) {
 	for _, entry := range typed.Sorted(appInstance.Status.AppSpec.Containers) {
 		if ports.IsLinked(appInstance, entry.Key) {
 			continue
 		}
-		dep, err := toDeployment(req, appInstance, tag, entry.Key, entry.Value, pullSecrets)
+		dep, err := toDeployment(req, appInstance, tag, entry.Key, entry.Value, pullSecrets, secrets)
+		if err != nil {
+			return nil, err
+		}
+		sa, err := toServiceAccount(req, dep.GetName(), dep.GetLabels(), dep.GetAnnotations(), appInstance)
 		if err != nil {
 			return nil, err
 		}
-		sa := toServiceAccount(dep.GetName(), dep.GetLabels(), dep.GetAnnotations(), appInstance)
 		if perms := v1.FindPermission(dep.GetName(), appInstance.Spec.Permissions); perms.HasRules() {
 			result = append(result, toPermissions(perms, dep.GetLabels(), dep.GetAnnotations(), appInstance)...)
 		}
-		result = append(result, dep, sa, expose.ToPodDisruptionBudget(dep))
+		result = append(result, sa, dep, pdb.ToPodDisruptionBudget(dep))
 	}
 	return result, nil
 }
-
-func addFileContent(configMap *corev1.ConfigMap, appName, deploymentName string, container v1.Container) error {
-	data := configMap.BinaryData
-	for filePath, file := range container.Files {
-		content, err := base64.StdEncoding.DecodeString(file.Content)
-		if err != nil {
-			return err
-		}
-		hashPath := pathHash(appName, deploymentName, deploymentName, filePath)
-		data[hashPath] = content
-		configMap.Annotations[hashPath] = path.Join(appName, deploymentName, deploymentName, filePath)
-	}
-	for sidecarName, sidecar := range container.Sidecars {
-		for filePath, file := range sidecar.Files {
-			content, err := base64.StdEncoding.DecodeString(file.Content)
-			if err != nil {
-				return err
-			}
-			hashPath := pathHash(appName, deploymentName, sidecarName, filePath)
-			data[hashPath] = content
-			configMap.Annotations[hashPath] = path.Join(appName, deploymentName, sidecarName, filePath)
-		}
-	}
-	return nil
-}
-
-func addConfigMaps(appInstance *v1.AppInstance, resp router.Response) error {
-	objs, err := toConfigMaps(appInstance)
-	resp.Objects(objs...)
-	return err
-}
-
-func toConfigMaps(appInstance *v1.AppInstance) (result []kclient.Object, err error) {
-	configMap := &corev1.ConfigMap{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      "files",
-			Namespace: appInstance.Status.Namespace,
-			Labels: map[string]string{
-				labels.AcornManaged: "true",
-			},
-			Annotations: map[string]string{},
-		},
-		BinaryData: map[string][]byte{},
-	}
-	for _, entry := range typed.Sorted(appInstance.Status.AppSpec.Containers) {
-		if err := addFileContent(configMap, appInstance.Name, entry.Key, entry.Value); err != nil {
-			return nil, err
-		}
-	}
-	for _, entry := range typed.Sorted(appInstance.Status.AppSpec.Jobs) {
-		if err := addFileContent(configMap, appInstance.Name, entry.Key, entry.Value); err != nil {
-			return nil, err
-		}
-	}
-	if len(configMap.BinaryData) == 0 {
-		return nil, nil
-	}
-
-	fileMode := getFilesFileModesForApp(appInstance)
-	for _, mode := range typed.SortedKeys(fileMode) {
-		if mode == "" {
-			result = append(result, configMap)
-		} else {
-			copy := configMap.DeepCopy()
-			copy.Name += "-" + mode
-			result = append(result, copy)
-		}
-	}
-
-	return result, nil
-}
