@@ -1,14 +1,14 @@
 package appdefinition
 
 import (
-	"encoding/hex"
-	"strings"
+	"encoding/base64"
 	"testing"
 
-	"cuelang.org/go/pkg/crypto/sha256"
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/controller/namespace"
+	"github.com/acorn-io/acorn/pkg/digest"
 	"github.com/acorn-io/acorn/pkg/scheme"
+	"github.com/acorn-io/acorn/pkg/secrets"
 	"github.com/acorn-io/baaah/pkg/router"
 	"github.com/acorn-io/baaah/pkg/router/tester"
 	"github.com/google/go-containerregistry/pkg/name"
@@ -76,11 +76,15 @@ func ToDeploymentsTest(t *testing.T, appInstance *v1.AppInstance, tag name.Refer
 	t.Helper()
 
 	req := tester.NewRequest(t, scheme.Scheme, appInstance)
-	deps, err := ToDeployments(req, appInstance, tag, pullSecrets)
+	interpolator := secrets.NewInterpolator(req.Ctx, req.Client, appInstance)
+	deps, err := ToDeployments(req, appInstance, tag, pullSecrets, interpolator)
 	if err != nil {
 		t.Fatal(err)
 	}
-	return deps
+	if err := interpolator.Err(); err != nil {
+		t.Fatal(err)
+	}
+	return append(deps, interpolator.Objects()...)
 }
 
 func TestEntrypointCommand(t *testing.T) {
@@ -95,7 +99,7 @@ func TestEntrypointCommand(t *testing.T) {
 				},
 			},
 		},
-	}, testTag, nil)[0].(*appsv1.Deployment)
+	}, testTag, nil)[1].(*appsv1.Deployment)
 	assert.Equal(t, []string{"hi", "bye"}, dep.Spec.Template.Spec.Containers[0].Command)
 	assert.Equal(t, []string{"hi2", "bye2"}, dep.Spec.Template.Spec.Containers[0].Args)
 }
@@ -119,7 +123,7 @@ func TestEnvironment(t *testing.T) {
 				},
 			},
 		},
-	}, testTag, nil)[0].(*appsv1.Deployment)
+	}, testTag, nil)[1].(*appsv1.Deployment)
 	assert.Equal(t, []corev1.EnvVar{
 		{
 			Name:  "hi",
@@ -143,7 +147,7 @@ func TestWorkdir(t *testing.T) {
 				},
 			},
 		},
-	}, testTag, nil)[0].(*appsv1.Deployment)
+	}, testTag, nil)[1].(*appsv1.Deployment)
 	assert.Equal(t, "something", dep.Spec.Template.Spec.Containers[0].WorkingDir)
 }
 
@@ -158,7 +162,7 @@ func TestInteractive(t *testing.T) {
 				},
 			},
 		},
-	}, testTag, nil)[0].(*appsv1.Deployment)
+	}, testTag, nil)[1].(*appsv1.Deployment)
 	assert.True(t, dep.Spec.Template.Spec.Containers[0].TTY)
 	assert.True(t, dep.Spec.Template.Spec.Containers[0].Stdin)
 }
@@ -183,7 +187,7 @@ func TestSidecar(t *testing.T) {
 				},
 			},
 		},
-	}, testTag, nil)[0].(*appsv1.Deployment)
+	}, testTag, nil)[1].(*appsv1.Deployment)
 	assert.Equal(t, "sidecar", dep.Spec.Template.Spec.InitContainers[0].Image)
 	assert.Equal(t, "sidecar2", dep.Spec.Template.Spec.Containers[1].Image)
 }
@@ -217,7 +221,7 @@ func TestPorts(t *testing.T) {
 				},
 			},
 		},
-	}, testTag, nil)[0].(*appsv1.Deployment)
+	}, testTag, nil)[1].(*appsv1.Deployment)
 	assert.Equal(t, int32(81), dep.Spec.Template.Spec.Containers[0].Ports[0].ContainerPort)
 	assert.Equal(t, corev1.ProtocolTCP, dep.Spec.Template.Spec.Containers[0].Ports[0].Protocol)
 	assert.Equal(t, int32(91), dep.Spec.Template.Spec.Containers[1].Ports[0].ContainerPort)
@@ -228,6 +232,7 @@ func TestFiles(t *testing.T) {
 	app := &v1.AppInstance{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: "app",
+			UID:  "123",
 		},
 		Status: v1.AppInstanceStatus{
 			AppSpec: v1.AppSpec{
@@ -273,40 +278,35 @@ func TestFiles(t *testing.T) {
 		},
 	}
 
-	dep := ToDeploymentsTest(t, app, testTag, nil)[0].(*appsv1.Deployment)
+	objs := ToDeploymentsTest(t, app, testTag, nil)
+	dep := objs[1].(*appsv1.Deployment)
 
-	assert.Equal(t, "files", dep.Spec.Template.Spec.Containers[0].VolumeMounts[0].Name)
-	assert.Equal(t, "/a1/b/c", dep.Spec.Template.Spec.Containers[0].VolumeMounts[0].MountPath)
-	assert.Equal(t, toPathHash("/app/test/test/a1/b/c"), dep.Spec.Template.Spec.Containers[0].VolumeMounts[0].SubPath)
-	assert.Equal(t, "files", dep.Spec.Template.Spec.Containers[0].VolumeMounts[1].Name)
-	assert.Equal(t, "/a2/b/c", dep.Spec.Template.Spec.Containers[0].VolumeMounts[1].MountPath)
-	assert.Equal(t, toPathHash("/app/test/test/a2/b/c"), dep.Spec.Template.Spec.Containers[0].VolumeMounts[1].SubPath)
-
-	assert.Equal(t, "files", dep.Spec.Template.Spec.Containers[1].VolumeMounts[0].Name)
-	assert.Equal(t, "/a/b1/c", dep.Spec.Template.Spec.Containers[1].VolumeMounts[0].MountPath)
-	assert.Equal(t, toPathHash("/app/test/left/a/b1/c"), dep.Spec.Template.Spec.Containers[1].VolumeMounts[0].SubPath)
-	assert.Equal(t, "files", dep.Spec.Template.Spec.Containers[1].VolumeMounts[1].Name)
-	assert.Equal(t, "/a/b2/c", dep.Spec.Template.Spec.Containers[1].VolumeMounts[1].MountPath)
-	assert.Equal(t, toPathHash("/app/test/left/a/b2/c"), dep.Spec.Template.Spec.Containers[1].VolumeMounts[1].SubPath)
-
-	configMaps, err := toConfigMaps(app)
-	if err != nil {
-		t.Fatal(err)
+	toHash := func(s string) string {
+		t.Helper()
+		data, err := base64.StdEncoding.DecodeString(s)
+		if err != nil {
+			t.Fatal(err)
+		}
+		return digest.SHA256(string(data))
 	}
-	configMap := configMaps[0].(*corev1.ConfigMap)
 
-	assert.Len(t, configMap.BinaryData, 8)
-	assert.Equal(t, []byte("d"), configMap.BinaryData[toPathHash("/app/test/test/a2/b/c")])
-	assert.Equal(t, []byte("d"), configMap.BinaryData[toPathHash("/app/test2/test2/a2/b/c")])
-	assert.Equal(t, []byte("d"), configMap.BinaryData[toPathHash("/app/test/left/a/b2/c")])
-	assert.Equal(t, []byte("d"), configMap.BinaryData[toPathHash("/app/test2/left/a/b2/c")])
-	assert.Equal(t, []byte("e"), configMap.BinaryData[toPathHash("/app/test/test/a1/b/c")])
-	assert.Equal(t, []byte("e"), configMap.BinaryData[toPathHash("/app/test/left/a/b1/c")])
-	assert.Equal(t, []byte("e"), configMap.BinaryData[toPathHash("/app/test2/test2/a1/b/c")])
-	assert.Equal(t, []byte("e"), configMap.BinaryData[toPathHash("/app/test2/left/a/b1/c")])
-}
+	assert.Equal(t, "secrets-123", dep.Spec.Template.Spec.Containers[0].VolumeMounts[0].Name)
+	assert.Equal(t, "/a1/b/c", dep.Spec.Template.Spec.Containers[0].VolumeMounts[0].MountPath)
+	assert.Equal(t, toHash("ZQ=="), dep.Spec.Template.Spec.Containers[0].VolumeMounts[0].SubPath)
+	assert.Equal(t, "secrets-123", dep.Spec.Template.Spec.Containers[0].VolumeMounts[1].Name)
+	assert.Equal(t, "/a2/b/c", dep.Spec.Template.Spec.Containers[0].VolumeMounts[1].MountPath)
+	assert.Equal(t, toHash("ZA=="), dep.Spec.Template.Spec.Containers[0].VolumeMounts[1].SubPath)
 
-func toPathHash(path string) string {
-	path = strings.TrimPrefix(path, "/")
-	return hex.EncodeToString(sha256.Sum256([]byte(path))[:])[:12]
+	assert.Equal(t, "secrets-123", dep.Spec.Template.Spec.Containers[1].VolumeMounts[0].Name)
+	assert.Equal(t, "/a/b1/c", dep.Spec.Template.Spec.Containers[1].VolumeMounts[0].MountPath)
+	assert.Equal(t, toHash("ZQ=="), dep.Spec.Template.Spec.Containers[1].VolumeMounts[0].SubPath)
+	assert.Equal(t, "secrets-123", dep.Spec.Template.Spec.Containers[1].VolumeMounts[1].Name)
+	assert.Equal(t, "/a/b2/c", dep.Spec.Template.Spec.Containers[1].VolumeMounts[1].MountPath)
+	assert.Equal(t, toHash("ZA=="), dep.Spec.Template.Spec.Containers[1].VolumeMounts[1].SubPath)
+
+	configMap := objs[6].(*corev1.Secret)
+
+	assert.Len(t, configMap.Data, 2)
+	assert.Equal(t, []byte("d"), configMap.Data[toHash("ZA==")])
+	assert.Equal(t, []byte("e"), configMap.Data[toHash("ZQ==")])
 }
