@@ -2,6 +2,7 @@ package appdefinition
 
 import (
 	"fmt"
+	"strings"
 
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/condition"
@@ -29,7 +30,8 @@ func AssignNamespace(req router.Request, resp router.Response) (err error) {
 	}
 
 	if appInstance.Spec.TargetNamespace == "" {
-		appInstance.Status.Namespace = name.SafeConcatName(appInstance.Name, appInstance.ShortID())
+		parts := strings.Split(appInstance.Name, ".")
+		appInstance.Status.Namespace = name.SafeConcatName(parts[len(parts)-1], appInstance.ShortID())
 	} else {
 		appInstance.Status.Namespace = appInstance.Spec.TargetNamespace
 	}
@@ -76,6 +78,9 @@ func IgnoreTerminatingNamespace(h router.Handler) router.Handler {
 
 func RequireNamespace(h router.Handler) router.Handler {
 	return router.HandlerFunc(func(req router.Request, resp router.Response) error {
+		if req.Object == nil {
+			return nil
+		}
 		appInstance := req.Object.(*v1.AppInstance)
 		if appInstance.Status.Namespace == "" {
 			return nil
