@@ -8,7 +8,10 @@ import (
 
 	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/acorn/pkg/labels"
+	"github.com/acorn-io/acorn/pkg/publicname"
+	"github.com/acorn-io/acorn/pkg/secrets"
 	"github.com/acorn-io/acorn/pkg/volume"
+	"github.com/acorn-io/baaah/pkg/name"
 	"github.com/acorn-io/baaah/pkg/router"
 	"github.com/acorn-io/baaah/pkg/typed"
 	"github.com/acorn-io/baaah/pkg/uncached"
@@ -50,13 +53,38 @@ func translateAccessModes(accessModes []v1.AccessMode) []corev1.PersistentVolume
 func lookupExistingPV(req router.Request, appInstance *v1.AppInstance, volumeName string) (string, error) {
 	var pvc corev1.PersistentVolumeClaim
 	if err := req.Get(&pvc, appInstance.Status.Namespace, volumeName); err == nil {
-		return pvc.Spec.VolumeName, nil
+		if pvc.Spec.VolumeName == "" {
+			return "", nil
+		}
+		pv := corev1.PersistentVolume{}
+		if err := req.Get(&pv, "", pvc.Spec.VolumeName); err == nil {
+			if pv.DeletionTimestamp.IsZero() {
+				return pvc.Spec.VolumeName, nil
+			}
+		} else if !apierrors.IsNotFound(err) {
+			return "", err
+		}
 	} else if !apierrors.IsNotFound(err) {
 		return "", err
 	}
 
+	// same thing as above but uncached
 	if err := req.Get(uncached.Get(&pvc), appInstance.Status.Namespace, volumeName); err == nil {
-		return pvc.Spec.VolumeName, nil
+		if pvc.Spec.VolumeName == "" {
+			return "", nil
+		}
+		pv := corev1.PersistentVolume{}
+		if err := req.Get(uncached.Get(&pv), "", pvc.Spec.VolumeName); err == nil {
+			if pv.DeletionTimestamp.IsZero() {
+				return pvc.Spec.VolumeName, nil
+			}
+		} else if !apierrors.IsNotFound(err) {
+			return "", err
+		}
+		// at this point we have to delete the PVC so that we can reset the invalid pvc.Spec.VolumeName
+		if err := req.Client.Delete(req.Ctx, &pvc); err != nil {
+			return "", err
+		}
 	} else if !apierrors.IsNotFound(err) {
 		return "", err
 	}
@@ -88,7 +116,7 @@ func lookupExistingPV(req router.Request, appInstance *v1.AppInstance, volumeNam
 }
 
 func toPVCs(req router.Request, appInstance *v1.AppInstance) (result []kclient.Object, err error) {
-	volumeClasses, _, err := volume.GetVolumeClasses(req.Ctx, req.Client, appInstance.Namespace)
+	volumeClasses, _, err := volume.GetVolumeClassInstances(req.Ctx, req.Client, appInstance.Namespace)
 	if err != nil {
 		return nil, err
 	}
@@ -125,8 +153,13 @@ func toPVCs(req router.Request, appInstance *v1.AppInstance) (result []kclient.O
 		}
 
 		if bind {
+			pv, err := getPVForVolumeBinding(req, appInstance, volumeBinding)
+			if err != nil {
+				return nil, err
+			}
+
 			pvc.Name = bindName(vol)
-			pvc.Spec.VolumeName = volumeBinding.Volume
+			pvc.Spec.VolumeName = pv.Name
 			pvc.Spec.Resources.Requests[corev1.ResourceStorage] = *v1.MinSize
 
 			if volumeBinding.Class != "" {
@@ -137,6 +170,9 @@ func toPVCs(req router.Request, appInstance *v1.AppInstance) (result []kclient.O
 					pvc.Spec.StorageClassName = &volClass.StorageClassName
 					pvc.Labels[labels.AcornVolumeClass] = volClass.Name
 				}
+			} else {
+				// User did not specify a class with the binding, so get the class from the existing volume.
+				pvc.Labels[labels.AcornVolumeClass] = pv.Labels[labels.AcornVolumeClass]
 			}
 
 			if volumeBinding.Size != "" {
@@ -170,19 +206,38 @@ func toPVCs(req router.Request, appInstance *v1.AppInstance) (result []kclient.O
 	return
 }
 
+func getPVForVolumeBinding(req router.Request, appInstance *v1.AppInstance, binding v1.VolumeBinding) (*corev1.PersistentVolume, error) {
+	pv := new(corev1.PersistentVolume)
+	if err := req.Client.Get(req.Ctx, kclient.ObjectKey{Name: binding.Volume}, pv); err != nil && !apierrors.IsNotFound(err) {
+		return nil, err
+	}
+
+	// make sure this PV is managed by acorn
+	if _, ok := pv.Labels[labels.AcornManaged]; !ok {
+		return nil, fmt.Errorf("no Acorn-managed volume found with name %q in project %q", binding.Volume, appInstance.Namespace)
+	}
+
+	// make sure this PV has the Acorn app namespace label with the same value as the AppInstance's namespace
+	if appNamespace, ok := pv.Labels[labels.AcornAppNamespace]; !ok || appNamespace != appInstance.Namespace {
+		return nil, fmt.Errorf("no Acorn-managed volume found with name %q in project %q", binding.Volume, appInstance.Namespace)
+	}
+	return pv, nil
+}
+
 func volumeLabels(appInstance *v1.AppInstance, volume string, volumeRequest v1.VolumeRequest) map[string]string {
 	labelMap := map[string]string{
 		labels.AcornAppName:      appInstance.Name,
 		labels.AcornAppNamespace: appInstance.Namespace,
 		labels.AcornManaged:      "true",
 		labels.AcornVolumeName:   volume,
+		labels.AcornPublicName:   publicname.ForChild(appInstance, volume),
 	}
 	return labels.Merge(labelMap, labels.GatherScoped(volume, v1.LabelTypeVolume, appInstance.Status.AppSpec.Labels,
 		volumeRequest.Labels, appInstance.Spec.Labels))
 }
 
 func isEphemeral(appInstance *v1.AppInstance, volume string) (v1.VolumeRequest, bool) {
-	if volume == AcornHelper && appInstance.Spec.GetDevMode() {
+	if volume == AcornHelper && appInstance.Status.GetDevMode() {
 		return v1.VolumeRequest{
 			Class: v1.VolumeRequestTypeEphemeral,
 		}, true
@@ -219,7 +274,7 @@ func addVolumeReferencesForContainer(app *v1.AppInstance, volumeReferences map[v
 	for _, entry := range typed.Sorted(container.Dirs) {
 		volume := entry.Value
 		if volume.ContextDir != "" {
-			if app.Spec.GetDevMode() {
+			if app.Status.GetDevMode() {
 				volumeReferences[volumeReference{name: AcornHelper}] = true
 			}
 		} else if volume.Secret.Name == "" {
@@ -244,7 +299,7 @@ type volumeReference struct {
 }
 
 func (v volumeReference) Suffix() string {
-	if normalizeMode(v.mode) == "" {
+	if volume.NormalizeMode(v.mode) == "" {
 		return ""
 	}
 	return "-" + v.mode
@@ -260,46 +315,32 @@ func toMode(m string) (*int32, error) {
 }
 
 func (v volumeReference) ParseMode() (*int32, error) {
-	if normalizeMode(v.mode) == "" {
+	if volume.NormalizeMode(v.mode) == "" {
 		return nil, nil
 	}
 	return toMode(v.mode)
 }
 
-func getFilesFileModesForApp(app *v1.AppInstance) map[string]bool {
-	fileModes := map[string]bool{}
-	for _, container := range app.Status.AppSpec.Containers {
-		addFilesFileModesForContainer(fileModes, container)
-	}
-	for _, container := range app.Status.AppSpec.Jobs {
-		addFilesFileModesForContainer(fileModes, container)
-	}
-	return fileModes
-}
-
-func normalizeMode(mode string) string {
-	if mode == "0644" || mode == "644" {
-		return ""
-	}
-	return mode
-}
-
 func addFilesFileModesForContainer(fileModes map[string]bool, container v1.Container) {
 	for _, file := range container.Files {
 		if file.Content != "" && file.Secret.Name == "" {
-			fileModes[normalizeMode(file.Mode)] = true
+			fileModes[volume.NormalizeMode(file.Mode)] = true
 		}
 	}
 	for _, sidecar := range container.Sidecars {
 		for _, file := range sidecar.Files {
 			if file.Content != "" && file.Secret.Name == "" {
-				fileModes[normalizeMode(file.Mode)] = true
+				fileModes[volume.NormalizeMode(file.Mode)] = true
 			}
 		}
 	}
 }
 
-func toVolumes(appInstance *v1.AppInstance, container v1.Container) (result []corev1.Volume, _ error) {
+func secretPodVolName(secretName string) string {
+	return strings.ReplaceAll(name.SafeConcatName("secret-", secretName), ".", "-")
+}
+
+func toVolumes(appInstance *v1.AppInstance, container v1.Container, interpolator *secrets.Interpolator) (result []corev1.Volume, _ error) {
 	volumeReferences := map[volumeReference]bool{}
 	addVolumeReferencesForContainer(appInstance, volumeReferences, container)
 	for _, entry := range typed.Sorted(container.Sidecars) {
@@ -313,7 +354,7 @@ func toVolumes(appInstance *v1.AppInstance, container v1.Container) (result []co
 				return nil, err
 			}
 			result = append(result, corev1.Volume{
-				Name: "secret--" + volume.secretName + volume.Suffix(),
+				Name: secretPodVolName(volume.secretName + volume.Suffix()),
 				VolumeSource: corev1.VolumeSource{
 					Secret: &corev1.SecretVolumeSource{
 						SecretName:  volume.secretName,
@@ -349,14 +390,15 @@ func toVolumes(appInstance *v1.AppInstance, container v1.Container) (result []co
 	fileModes := map[string]bool{}
 	addFilesFileModesForContainer(fileModes, container)
 
+	secretName := interpolator.SecretName()
 	for _, modeString := range typed.SortedKeys(fileModes) {
-		name := "files"
 		var (
 			mode *int32
 			err  error
+			name = interpolator.SecretName()
 		)
 		if modeString != "" {
-			name = "files-" + modeString
+			name = name + "-" + modeString
 			mode, err = toMode(modeString)
 			if err != nil {
 				return nil, err
@@ -365,11 +407,9 @@ func toVolumes(appInstance *v1.AppInstance, container v1.Container) (result []co
 		result = append(result, corev1.Volume{
 			Name: name,
 			VolumeSource: corev1.VolumeSource{
-				ConfigMap: &corev1.ConfigMapVolumeSource{
+				Secret: &corev1.SecretVolumeSource{
 					DefaultMode: mode,
-					LocalObjectReference: corev1.LocalObjectReference{
-						Name: name,
-					},
+					SecretName:  secretName,
 				},
 			},
 		})
