@@ -13,6 +13,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	kclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
 func TestVolumeController(t *testing.T) {
@@ -165,3 +166,135 @@ func TestVolumeLabelsAnnotations(t *testing.T) {
 	assert.Contains(t, pvc2.Annotations, "globalfromacornfilea")
 	assert.NotContains(t, pvc2.Annotations, "vol1fromacornfilea")
 }
+
+func TestFindPVForBinding(t *testing.T) {
+	pvList := buildPVs(t)
+	err := scheme.AddToScheme(scheme.Scheme)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	tests := []struct {
+		name                string
+		appInstance         v1.AppInstance
+		volumeBinding       v1.VolumeBinding
+		expectedPVName      string
+		expectNotFoundError bool
+		extraPV             *corev1.PersistentVolume
+	}{
+		{
+			name: "Bind nonexistent PV",
+			appInstance: v1.AppInstance{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "myApp",
+					Namespace: "proj1",
+				},
+			},
+			volumeBinding: v1.VolumeBinding{
+				Volume: "dne",
+				Target: "targetVol",
+			},
+			expectNotFoundError: true,
+		},
+		{
+			name: "Bind PV created by another app, same project",
+			appInstance: v1.AppInstance{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "myApp",
+					Namespace: "proj1",
+				},
+			},
+			volumeBinding: v1.VolumeBinding{
+				Volume: "pv2",
+				Target: "targetVol",
+			},
+			expectedPVName: "pv2",
+		},
+		{
+			name: "Bind PV created by another app, different project",
+			appInstance: v1.AppInstance{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "myApp",
+					Namespace: "proj1",
+				},
+			},
+			volumeBinding: v1.VolumeBinding{
+				Volume: "pv3",
+				Target: "targetVol",
+			},
+			expectNotFoundError: true,
+		},
+		{
+			name: "Bind PV created outside of Acorn",
+			appInstance: v1.AppInstance{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "myApp",
+					Namespace: "proj1",
+				},
+			},
+			volumeBinding: v1.VolumeBinding{
+				Volume: "not-acorn-managed",
+				Target: "targetVol",
+			},
+			expectNotFoundError: true,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			req := tester.NewRequest(t, scheme.Scheme, &tt.appInstance, pvList...)
+
+			if tt.extraPV != nil {
+				if err := req.Client.Create(req.Ctx, tt.extraPV); err != nil {
+					t.Fatal(err)
+				}
+			}
+
+			pv, err := getPVForVolumeBinding(req, &tt.appInstance, tt.volumeBinding)
+			if err != nil {
+				if !strings.Contains(err.Error(), "no Acorn-managed volume found") || !tt.expectNotFoundError {
+					t.Fatalf("Unexpected error: %v", err)
+				}
+			} else if tt.expectNotFoundError {
+				t.Fatalf("Found PersistentVolume [%s] when none was expected", pv.Name)
+			} else if pv.Name != tt.expectedPVName {
+				t.Fatalf("Expected PersistentVolume [%s] but found [%s]", tt.expectedPVName, pv.Name)
+			}
+		})
+	}
+}
+
+func buildPVs(t *testing.T) []kclient.Object {
+	t.Helper()
+
+	pvList := []kclient.Object{
+		&corev1.PersistentVolume{
+			ObjectMeta: metav1.ObjectMeta{
+				Name: "pv2",
+				Labels: map[string]string{
+					labels.AcornAppNamespace: "proj1",
+					labels.AcornPublicName:   "app2.volume",
+					labels.AcornManaged:      "true",
+				},
+			},
+		},
+		&corev1.PersistentVolume{
+			ObjectMeta: metav1.ObjectMeta{
+				Name: "pv3",
+				Labels: map[string]string{
+					labels.AcornAppNamespace: "other-project",
+					labels.AcornPublicName:   "app3.volume",
+					labels.AcornManaged:      "true",
+				},
+			},
+		},
+		&corev1.PersistentVolume{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:   "not-acorn-managed",
+				Labels: map[string]string{},
+			},
+		},
+	}
+
+	return pvList
+}
