@@ -26,7 +26,7 @@ import (
 	utilerrors "k8s.io/apimachinery/pkg/util/errors"
 )
 
-// ProvisionWildcardCert provisions a Let's Encrypt wildcard certificate for *.<domain>.on-acorn.io
+// ProvisionWildcardCert provisions a Let's Encrypt wildcard certificate for *.<domain>.oss-acorn.io
 func ProvisionWildcardCert(req router.Request, resp router.Response, domain, token string) error {
 	logrus.Debugf("Provisioning wildcard cert for %v", domain)
 	// Ensure that we have a Let's Encrypt account ready
@@ -41,7 +41,6 @@ func ProvisionWildcardCert(req router.Request, resp router.Response, domain, tok
 
 	// Generate wildcard certificate for domain
 	return leUser.provisionCertIfNotExists(req.Ctx, req.Client, wildcardDomain, system.Namespace, system.TLSSecretName)
-
 }
 
 // RequireSecretTypeTLS is a middleware that ensures that we only act on TLS-Type secrets
@@ -77,7 +76,6 @@ func RenewCert(req router.Request, resp router.Response) error {
 	domain := sec.Annotations[labels.AcornDomain]
 
 	go func() {
-
 		// Do not start a new challenge if we already have one in progress
 		if !lockDomain(domain) {
 			logrus.Debugf("not starting certificate renewal: %v: %s", ErrCertificateRequestInProgress, domain)
@@ -108,16 +106,13 @@ func RenewCert(req router.Request, resp router.Response) error {
 		}
 
 		logrus.Infof("TLS secret %s/%s renewed for domain %s", newSec.Namespace, newSec.Name, domain)
-
 	}()
 
 	return nil
-
 }
 
 // ProvisionCerts handles the provisioning of new TLS certificates for AppInstances
 func ProvisionCerts(req router.Request, resp router.Response) error {
-
 	cfg, err := config.Get(req.Ctx, req.Client)
 	if err != nil {
 		return err
@@ -143,7 +138,7 @@ func ProvisionCerts(req router.Request, resp router.Response) error {
 	provisionedCerts := map[string]interface{}{}
 	var errs []error
 
-	for i, ep := range appInstance.Status.Endpoints {
+	for i, ep := range appInstance.Status.AppStatus.Endpoints {
 		if ep.Protocol != "http" {
 			continue
 		}
@@ -153,26 +148,26 @@ func ProvisionCerts(req router.Request, resp router.Response) error {
 		}
 		provisionedCerts[ep.Address] = nil
 		ep.PublishProtocol = v1.PublishProtocolHTTPS
-		appInstance.Status.Endpoints[i] = ep
+		appInstance.Status.AppStatus.Endpoints[i] = ep
 	}
 
-	for _, pb := range appInstance.Spec.Ports {
-		if _, ok := provisionedCerts[pb.ServiceName]; ok {
+	for _, pb := range appInstance.Spec.Publish {
+		if _, ok := provisionedCerts[pb.Hostname]; ok {
 			continue
 		}
-		if err := prov(req, leUser, pb.ServiceName, appInstance.Name, appInstanceIDSegment, appInstance.Namespace); err != nil {
+		if err := prov(req, leUser, pb.Hostname, appInstance.Name, appInstanceIDSegment, appInstance.Namespace); err != nil {
 			errs = append(errs, err)
 			continue
 		}
-		provisionedCerts[pb.ServiceName] = nil
+		provisionedCerts[pb.Hostname] = nil
 	}
 
 	return utilerrors.NewAggregate(errs)
 }
 
 func prov(req router.Request, leUser *LEUser, domain, appname, segment, namespace string) error {
-	if domain == "" || len(validation.IsFullyQualifiedDomainName(&field.Path{}, domain)) > 0 || strings.HasSuffix(domain, "on-acorn.io") {
-		logrus.Warnf("Skipping cert provisioning for %s", domain)
+	if domain == "" || len(validation.IsFullyQualifiedDomainName(&field.Path{}, domain)) > 0 || strings.HasSuffix(domain, "oss-acorn.io") {
+		logrus.Debugf("Skipping cert provisioning for %s", domain)
 		return nil
 	}
 	secretName := name.Limit(appname+"-tls-"+domain, 63-len(segment)-1) + "-" + segment
@@ -225,61 +220,67 @@ func findExistingCertSecret(ctx context.Context, client kclient.Client, target s
 				return &sec, nil
 			}
 		}
-
 	}
 	return nil, nil
 }
 
 func (u *LEUser) provisionCertIfNotExists(ctx context.Context, client kclient.Client, domain string, namespace string, secretName string) error {
-	// Find existing secret if exists
+	// Find existing secret by expected name
 	existingSecret := &corev1.Secret{}
 	findSecretErr := client.Get(ctx, router.Key(namespace, secretName), existingSecret)
+	var mustUpdate bool
 	if findSecretErr == nil {
-		// Skip: TLS secret already exists, nothing to do here, renewal will be handled elsewhere
-		return nil
-	} else if !apierrors.IsNotFound(findSecretErr) {
-		// Not found is ok, we'll create the secret below.. other errors are bad
-		logrus.Errorf("Error getting secret %s/%s: %v", namespace, secretName, findSecretErr)
-		return findSecretErr
-	}
-
-	// Let's see if we have some existing certificate that matches the domain
-	existingSecret, err := findExistingCertSecret(ctx, client, domain)
-	if err != nil {
-		return err
-	}
-	if existingSecret != nil {
-		// We found an existing certificate
-		// 1. It's in the same namespace, so it will be picked up automatically
-		if existingSecret.Namespace == namespace {
-			logrus.Debugf("Found existing TLS secret %s/%s for domain %s", existingSecret.Namespace, existingSecret.Name, domain)
-			// Skip: TLS secret already exists, nothing to do here, renewal will be handled elsewhere
+		if existingSecret.Annotations[labels.AcornDomain] == domain {
+			// Skip: TLS secret already exists and matches the domain, nothing to do here, renewal will be handled elsewhere
+			logrus.Debugf("No need to provision cert for domain %s, secret for that domain already exists: %s/%s", domain, existingSecret.Namespace, existingSecret.Name)
 			return nil
 		}
+		// There's an existing secret with a different domain but matching the expected name, so we'll update it
+		logrus.Debugf("Updating existing secret %s/%s with domain %s to %s", existingSecret.Namespace, existingSecret.Name, existingSecret.Annotations[labels.AcornDomain], domain)
+		mustUpdate = true
+	} else if !apierrors.IsNotFound(findSecretErr) {
+		// Not found is ok, we'll create the secret below.. other errors are bad
+		return fmt.Errorf("Error getting certificate secret %s/%s: %w", namespace, secretName, findSecretErr)
+	}
 
-		logrus.Debugf("Found existing TLS secret %s/%s for domain %s, copying to %s/%s", existingSecret.Namespace, existingSecret.Name, domain, namespace, secretName)
-
-		// 2. Copy secret to new namespace
-		copiedSecret := &corev1.Secret{
-			ObjectMeta: metav1.ObjectMeta{
-				Name:      secretName,
-				Namespace: namespace,
-				Labels: map[string]string{
-					labels.AcornManaged: "true",
-				},
-				Annotations: map[string]string{
-					labels.AcornDomain: domain,
-				},
-			},
-			Data: existingSecret.Data,
-			Type: existingSecret.Type,
-		}
-
-		if err := client.Create(ctx, copiedSecret); err != nil {
-			logrus.Errorf("Error creating TLS secret %s/%s: %v", copiedSecret.Namespace, copiedSecret.Name, err)
+	if !mustUpdate {
+		// Let's see if we have some existing certificate that matches the domain
+		existingSecret, err := findExistingCertSecret(ctx, client, domain)
+		if err != nil {
 			return err
 		}
-		return nil
+		if existingSecret != nil {
+			// We found an existing certificate
+			// 1. It's in the same namespace, so it will be picked up automatically
+			if existingSecret.Namespace == namespace {
+				logrus.Debugf("Found existing TLS secret %s/%s for domain %s", existingSecret.Namespace, existingSecret.Name, domain)
+				// Skip: TLS secret already exists, nothing to do here, renewal will be handled elsewhere
+				return nil
+			}
+
+			logrus.Debugf("Found existing TLS secret %s/%s for domain %s, copying to %s/%s", existingSecret.Namespace, existingSecret.Name, domain, namespace, secretName)
+
+			// 2. Copy secret to new namespace
+			copiedSecret := &corev1.Secret{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      secretName,
+					Namespace: namespace,
+					Labels: map[string]string{
+						labels.AcornManaged: "true",
+					},
+					Annotations: map[string]string{
+						labels.AcornDomain: domain,
+					},
+				},
+				Data: existingSecret.Data,
+				Type: existingSecret.Type,
+			}
+
+			if err := client.Create(ctx, copiedSecret); err != nil {
+				return fmt.Errorf("Error creating TLS secret %s/%s: %w", copiedSecret.Namespace, copiedSecret.Name, err)
+			}
+			return nil
+		}
 	}
 
 	go func() {
@@ -290,10 +291,10 @@ func (u *LEUser) provisionCertIfNotExists(ctx context.Context, client kclient.Cl
 		}
 		defer unlockDomain(domain)
 
-		logrus.Infof("Provisioning TLS cert for %v in secret %s/%s", domain, namespace, secretName)
+		logrus.Infof("Provisioning TLS cert for %s in secret %s/%s", domain, namespace, secretName)
 		cert, err := u.getCert(ctx, domain)
 		if err != nil {
-			logrus.Errorf("Error getting cert for %v: %v", domain, err)
+			logrus.Errorf("Error getting cert for %s: %v", domain, err)
 			return
 		}
 
@@ -303,6 +304,15 @@ func (u *LEUser) provisionCertIfNotExists(ctx context.Context, client kclient.Cl
 			return
 		}
 
+		if mustUpdate {
+			if err := client.Update(ctx, newSec); err != nil {
+				logrus.Errorf("error updating TLS secret %s/%s: %v", namespace, secretName, err)
+				return
+			}
+			logrus.Infof("TLS secret %s/%s updated for domain %s", namespace, secretName, domain)
+			return
+		}
+
 		if err := client.Create(ctx, newSec); err != nil {
 			logrus.Errorf("error creating TLS secret %s/%s: %v", namespace, secretName, err)
 			return
