@@ -4,7 +4,10 @@ import (
 	"fmt"
 	"path/filepath"
 
+	v1 "github.com/acorn-io/acorn/pkg/apis/internal.acorn.io/v1"
+	"github.com/acorn-io/acorn/pkg/labels"
 	"github.com/acorn-io/acorn/pkg/system"
+	"github.com/acorn-io/acorn/pkg/tolerations"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	policyv1 "k8s.io/api/policy/v1"
@@ -13,29 +16,7 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client"
 )
 
-func BuilderObjects(name, namespace, forNamespace, buildKitImage, pub, privKey, builderUID, forwardAddress string, useCustomCabundle bool) []client.Object {
-	service := &corev1.Service{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      name,
-			Namespace: namespace,
-		},
-		Spec: corev1.ServiceSpec{
-			Ports: []corev1.ServicePort{
-				{
-					Name:     system.BuildKitName,
-					Protocol: corev1.ProtocolTCP,
-					Port:     int32(system.BuildkitPort),
-					TargetPort: intstr.IntOrString{
-						IntVal: int32(system.BuildkitPort),
-					},
-				},
-			},
-			Selector: map[string]string{
-				"app": name,
-			},
-			Type: corev1.ServiceTypeClusterIP,
-		},
-	}
+func BuilderObjects(name, namespace, forNamespace, buildKitImage, pub, privKey, builderUID, forwardAddress string, useCustomCabundle, publishBuilder bool) []client.Object {
 	secret := &corev1.Secret{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      name,
@@ -54,15 +35,11 @@ func BuilderObjects(name, namespace, forNamespace, buildKitImage, pub, privKey,
 		},
 		Spec: appsv1.DeploymentSpec{
 			Selector: &metav1.LabelSelector{
-				MatchLabels: map[string]string{
-					"app": name,
-				},
+				MatchLabels: labels.ManagedByApp(namespace, name, "app", name),
 			},
 			Template: corev1.PodTemplateSpec{
 				ObjectMeta: metav1.ObjectMeta{
-					Labels: map[string]string{
-						"app": name,
-					},
+					Labels: labels.ManagedByApp(namespace, name, "app", name),
 				},
 				Spec: corev1.PodSpec{
 					ServiceAccountName: "acorn-builder",
@@ -108,7 +85,7 @@ func BuilderObjects(name, namespace, forNamespace, buildKitImage, pub, privKey,
 							},
 							Ports: []corev1.ContainerPort{
 								{
-									ContainerPort: int32(system.BuildkitPort),
+									ContainerPort: system.BuildkitPort,
 								},
 							},
 							VolumeMounts: []corev1.VolumeMount{
@@ -163,10 +140,9 @@ func BuilderObjects(name, namespace, forNamespace, buildKitImage, pub, privKey,
 							},
 							ReadinessProbe: &corev1.Probe{
 								ProbeHandler: corev1.ProbeHandler{
-									TCPSocket: &corev1.TCPSocketAction{
-										Port: intstr.IntOrString{
-											IntVal: int32(system.BuildkitPort),
-										},
+									HTTPGet: &corev1.HTTPGetAction{
+										Path: "/ping",
+										Port: intstr.IntOrString{IntVal: system.BuildkitPort},
 									},
 								},
 								InitialDelaySeconds: 2,
@@ -174,7 +150,7 @@ func BuilderObjects(name, namespace, forNamespace, buildKitImage, pub, privKey,
 							},
 							Ports: []corev1.ContainerPort{
 								{
-									ContainerPort: int32(system.BuildkitPort),
+									ContainerPort: system.BuildkitPort,
 								},
 							},
 							VolumeMounts: []corev1.VolumeMount{
@@ -193,6 +169,12 @@ func BuilderObjects(name, namespace, forNamespace, buildKitImage, pub, privKey,
 							},
 						},
 					},
+					Tolerations: []corev1.Toleration{
+						{
+							Key:      tolerations.WorkloadTolerationKey,
+							Operator: corev1.TolerationOpExists,
+						},
+					},
 				},
 			},
 		},
@@ -209,6 +191,32 @@ func BuilderObjects(name, namespace, forNamespace, buildKitImage, pub, privKey,
 		},
 	}
 
+	svc := &v1.ServiceInstance{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      name,
+			Namespace: system.ImagesNamespace,
+			Labels: map[string]string{
+				labels.AcornAppName:      name,
+				labels.AcornAppNamespace: system.ImagesNamespace,
+			},
+		},
+		Spec: v1.ServiceInstanceSpec{
+			AppName:      name,
+			AppNamespace: system.ImagesNamespace,
+			ContainerLabels: map[string]string{
+				"app": name,
+			},
+			Labels: labels.ManagedByApp(system.ImagesNamespace, name),
+			Ports: []v1.PortDef{
+				{
+					Port:     8080,
+					Protocol: v1.ProtocolHTTP,
+					Publish:  publishBuilder,
+				},
+			},
+		},
+	}
+
 	if useCustomCabundle {
 		for i := range deployment.Spec.Template.Spec.Containers {
 			deployment.Spec.Template.Spec.Containers[i].VolumeMounts = append(deployment.Spec.Template.Spec.Containers[i].VolumeMounts, corev1.VolumeMount{
@@ -227,5 +235,5 @@ func BuilderObjects(name, namespace, forNamespace, buildKitImage, pub, privKey,
 			},
 		})
 	}
-	return []client.Object{secret, service, deployment, pdb}
+	return []client.Object{secret, deployment, pdb, svc}
 }
