@@ -2,6 +2,7 @@ package imagesystem
 
 import (
 	"github.com/acorn-io/acorn/pkg/system"
+	"github.com/acorn-io/acorn/pkg/tolerations"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	policyv1 "k8s.io/api/policy/v1"
@@ -119,6 +120,12 @@ func registryDeployment(namespace, registryImage string) []client.Object {
 							Name: "registry",
 						},
 					},
+					Tolerations: []corev1.Toleration{
+						{
+							Key:      tolerations.WorkloadTolerationKey,
+							Operator: corev1.TolerationOpExists,
+						},
+					},
 				},
 			},
 		},
