@@ -56,12 +56,13 @@ var (
 type Mode string
 
 type Options struct {
-	SkipChecks         bool
-	OutputFormat       string
-	APIServerReplicas  *int
-	ControllerReplicas *int
-	Config             apiv1.Config
-	Progress           progress.Builder
+	SkipChecks                          bool
+	OutputFormat                        string
+	APIServerReplicas                   *int
+	ControllerReplicas                  *int
+	ControllerServiceAccountAnnotations map[string]string
+	Config                              apiv1.Config
+	Progress                            progress.Builder
 }
 
 func (o *Options) complete() *Options {
@@ -156,6 +157,10 @@ func Install(ctx context.Context, image string, opts *Options) error {
 		return err
 	}
 
+	if err = validateServiceLBAnnotations(finalConfForValidation.ServiceLBAnnotations); err != nil {
+		return err
+	}
+
 	opts = opts.complete()
 	if opts.OutputFormat != "" {
 		return printObject(image, opts)
@@ -213,7 +218,8 @@ func Install(ctx context.Context, image string, opts *Options) error {
 	s.Success()
 
 	s = opts.Progress.New(fmt.Sprintf("Installing APIServer and Controller (image %s)", image))
-	if err := applyDeployments(ctx, image, *opts.APIServerReplicas, *opts.ControllerReplicas, *opts.Config.UseCustomCABundle, apply, c); err != nil {
+	if err := applyDeployments(ctx, image, *opts.APIServerReplicas, *opts.ControllerReplicas, *opts.Config.UseCustomCABundle,
+		opts.ControllerServiceAccountAnnotations, apply, c); err != nil {
 		return s.Fail(err)
 	}
 	s.Success()
@@ -258,6 +264,16 @@ func Install(ctx context.Context, image string, opts *Options) error {
 	return nil
 }
 
+func validateServiceLBAnnotations(annotations []string) error {
+	for _, annotation := range annotations {
+		_, _, found := strings.Cut(annotation, "=")
+		if !found {
+			return fmt.Errorf("invalid annotation %s, must be in the form of key=value", annotation)
+		}
+	}
+	return nil
+}
+
 func validateMemoryArgs(defaultMemory int64, maximumMemory int64) error {
 	// if default is set to unrestricted memory (0) and max memory is not default will be set to maximum
 	if defaultMemory == 0 && maximumMemory != 0 {
@@ -292,7 +308,6 @@ func TraefikResources() (result []kclient.Object, _ error) {
 		}
 		labels[labels2.AcornManaged] = "true"
 		m.SetLabels(labels)
-
 	}
 
 	return objs, nil
@@ -419,7 +434,8 @@ func resources(image string, opts *Options) ([]kclient.Object, error) {
 	}
 	objs = append(objs, namespace...)
 
-	deps, err := Deployments(image, *opts.APIServerReplicas, *opts.ControllerReplicas, *opts.Config.UseCustomCABundle)
+	deps, err := Deployments(image, *opts.APIServerReplicas, *opts.ControllerReplicas, *opts.Config.UseCustomCABundle,
+		opts.ControllerServiceAccountAnnotations)
 	if err != nil {
 		return nil, err
 	}
@@ -460,7 +476,7 @@ func printObject(image string, opts *Options) error {
 	return err
 }
 
-func applyDeployments(ctx context.Context, imageName string, apiServerReplicas, controllerReplicas int, useCustomCABundle bool, apply apply.Apply, c kclient.Client) error {
+func applyDeployments(ctx context.Context, imageName string, apiServerReplicas, controllerReplicas int, useCustomCABundle bool, annotations map[string]string, apply apply.Apply, c kclient.Client) error {
 	// handle upgrade from <= v0.3.x
 	if err := resetNamespace(ctx, c); err != nil {
 		return err
@@ -471,7 +487,7 @@ func applyDeployments(ctx context.Context, imageName string, apiServerReplicas,
 		return err
 	}
 
-	deps, err := Deployments(imageName, apiServerReplicas, controllerReplicas, useCustomCABundle)
+	deps, err := Deployments(imageName, apiServerReplicas, controllerReplicas, useCustomCABundle, annotations)
 	if err != nil {
 		return err
 	}
@@ -511,7 +527,7 @@ func Namespace() ([]kclient.Object, error) {
 	return objectsFromFile("namespace.yaml")
 }
 
-func Deployments(runtimeImage string, apiServerReplicas, controllerReplicas int, useCustomCABundle bool) ([]kclient.Object, error) {
+func Deployments(runtimeImage string, apiServerReplicas, controllerReplicas int, useCustomCABundle bool, annotations map[string]string) ([]kclient.Object, error) {
 	apiServerObjects, err := objectsFromFile("apiserver.yaml")
 	if err != nil {
 		return nil, err
@@ -532,6 +548,11 @@ func Deployments(runtimeImage string, apiServerReplicas, controllerReplicas int,
 		return nil, err
 	}
 
+	controllerObjects, err = replaceAnnotations(annotations, controllerObjects)
+	if err != nil {
+		return nil, err
+	}
+
 	var objects []kclient.Object
 	objects = append(apiServerObjects, controllerObjects...)
 	if useCustomCABundle {
@@ -544,6 +565,29 @@ func Deployments(runtimeImage string, apiServerReplicas, controllerReplicas int,
 	return replaceImage(runtimeImage, objects)
 }
 
+func replaceAnnotations(annotations map[string]string, objs []kclient.Object) ([]kclient.Object, error) {
+	val := map[string]any{}
+	for k, v := range annotations {
+		val[k] = v
+	}
+
+	if len(val) == 0 {
+		return objs, nil
+	}
+
+	for _, obj := range objs {
+		ustr := obj.(*unstructured.Unstructured)
+		if ustr.GetKind() == "ServiceAccount" {
+			err := unstructured.SetNestedField(ustr.Object, val, "metadata", "annotations")
+			if err != nil {
+				return nil, err
+			}
+		}
+	}
+
+	return objs, nil
+}
+
 func replaceReplicas(replicas int, objs []kclient.Object) ([]kclient.Object, error) {
 	for _, obj := range objs {
 		ustr := obj.(*unstructured.Unstructured)
