@@ -10,45 +10,53 @@ import (
 )
 
 const (
-	Prefix                       = "acorn.io/"
-	AcornAppGeneration           = Prefix + "app-generation"
-	AcornAppNamespace            = Prefix + "app-namespace"
-	AcornAppName                 = Prefix + "app-name"
-	AcornAcornName               = Prefix + "acorn-name"
-	AcornServiceName             = Prefix + "service-name"
-	AcornServicePublish          = Prefix + "service-publish"
-	AcornServiceNamePrefix       = "service-name." + Prefix
-	AcornDepNames                = Prefix + "dep-names"
-	AcornAppUID                  = Prefix + "app-uid"
-	AcornVolumeName              = Prefix + "volume-name"
-	AcornVolumeClass             = Prefix + "volume-class"
-	AcornSecretName              = Prefix + "secret-name"
-	AcornSecretGenerated         = Prefix + "secret-generated"
-	AcornContainerName           = Prefix + "container-name"
-	AcornRouterName              = Prefix + "router-name"
-	AcornJobName                 = Prefix + "job-name"
-	AcornAppImage                = Prefix + "app-image"
-	AcornAppCuePath              = Prefix + "app-cue-path"
-	AcornAppCuePathHash          = Prefix + "app-cue-path-hash"
-	AcornManaged                 = Prefix + "managed"
-	AcornContainerSpec           = Prefix + "container-spec"
-	AcornImageMapping            = Prefix + "image-mapping"
-	AcornPortNumberPrefix        = "port-number." + Prefix
-	AcornCredential              = Prefix + "credential"
-	AcornPullSecret              = Prefix + "pull-secret"
-	AcornSecretRevPrefix         = "secret-rev." + Prefix
-	AcornPublishURL              = Prefix + "publish-url"
-	AcornTargets                 = Prefix + "targets"
-	AcornDNSHash                 = Prefix + "dns-hash"
-	AcornLinkName                = Prefix + "link-name"
-	AcornDNSState                = Prefix + "applied-dns-state"
-	AcornDebugShell              = Prefix + "debug-shell"
-	AcornDomain                  = Prefix + "domain"
-	AcornCertNotValidBefore      = Prefix + "cert-not-valid-before"
-	AcornCertNotValidAfter       = Prefix + "cert-not-valid-after"
-	AcornLetsEncryptSettingsHash = Prefix + "le-hash"
-	AcornProject                 = Prefix + "project"
-	AcornProjectName             = Prefix + "project-name"
+	Prefix                              = "acorn.io/"
+	AcornAccountID                      = Prefix + "account-id"
+	AcornAppGeneration                  = Prefix + "app-generation"
+	AcornAppNamespace                   = Prefix + "app-namespace"
+	AcornAppName                        = Prefix + "app-name"
+	AcornParentAcornName                = Prefix + "parent-acorn-name"
+	AcornAppPublicName                  = Prefix + "app-public-name"
+	AcornPublicName                     = Prefix + "public-name"
+	AcornAcornName                      = Prefix + "acorn-name"
+	AcornServiceName                    = Prefix + "service-name"
+	AcornServicePublish                 = Prefix + "service-publish"
+	AcornServiceNamePrefix              = "service-name." + Prefix
+	AcornDepNames                       = Prefix + "dep-names"
+	AcornAppUID                         = Prefix + "app-uid"
+	AcornVolumeName                     = Prefix + "volume-name"
+	AcornVolumeClass                    = Prefix + "volume-class"
+	AcornSecretName                     = Prefix + "secret-name"
+	AcornSecretSourceName               = Prefix + "secret-source-name"
+	AcornSecretGenerated                = Prefix + "secret-generated"
+	AcornContainerName                  = Prefix + "container-name"
+	AcornRouterName                     = Prefix + "router-name"
+	AcornJobName                        = Prefix + "job-name"
+	AcornAppImage                       = Prefix + "app-image"
+	AcornAppDevHash                     = Prefix + "app-dev-hash"
+	AcornManaged                        = Prefix + "managed"
+	AcornContainerSpec                  = Prefix + "container-spec"
+	AcornImageMapping                   = Prefix + "image-mapping"
+	AcornOriginalImage                  = Prefix + "original-image"
+	AcornPortNumberPrefix               = "port-number." + Prefix
+	AcornCredential                     = Prefix + "credential"
+	AcornPullSecret                     = Prefix + "pull-secret"
+	AcornSecretRevPrefix                = "secret-rev." + Prefix
+	AcornPublishURL                     = Prefix + "publish-url"
+	AcornTargets                        = Prefix + "targets"
+	AcornDNSHash                        = Prefix + "dns-hash"
+	AcornLinkName                       = Prefix + "link-name"
+	AcornDNSState                       = Prefix + "applied-dns-state"
+	AcornDomain                         = Prefix + "domain"
+	AcornCertNotValidBefore             = Prefix + "cert-not-valid-before"
+	AcornCertNotValidAfter              = Prefix + "cert-not-valid-after"
+	AcornLetsEncryptSettingsHash        = Prefix + "le-hash"
+	AcornProject                        = Prefix + "project"
+	AcornProjectName                    = Prefix + "project-name"
+	AcornProjectDefaultRegion           = Prefix + "project-default-region"
+	AcornProjectSupportedRegions        = Prefix + "project-supported-regions"
+	AcornCalculatedProjectDefaultRegion = Prefix + "calculated-project-default-region"
+	ProjectEnforcedQuotaAnnotation      = Prefix + "enforced-quota"
 )
 
 func Merge(base, overlay map[string]string) map[string]string {
@@ -71,10 +79,10 @@ func ExcludeAcornKey(input map[string]string) map[string]string {
 	return result
 }
 
-func Managed(appInstance *v1.AppInstance, kv ...string) map[string]string {
+func ManagedByApp(appNamespace, appName string, kv ...string) map[string]string {
 	labels := map[string]string{
-		AcornAppName:      appInstance.Name,
-		AcornAppNamespace: appInstance.Namespace,
+		AcornAppName:      appName,
+		AcornAppNamespace: appNamespace,
 		AcornManaged:      "true",
 	}
 	for i := 0; i+1 < len(kv); i += 2 {
@@ -87,6 +95,10 @@ func Managed(appInstance *v1.AppInstance, kv ...string) map[string]string {
 	return labels
 }
 
+func Managed(appInstance *v1.AppInstance, kv ...string) map[string]string {
+	return ManagedByApp(appInstance.Namespace, appInstance.Name, kv...)
+}
+
 // GatherScoped takes in labels (or annotations) from the various places they can appear in an acorn app and sifts through
 // them to build a map of the ones that apply to the resource specified by the supplied resourceName and resourceType.
 // `globalLabels` would be labels defined at top of an Acornfile, as sibling to containers. These apply to all resources, thus "global."
@@ -142,6 +154,24 @@ func FilterUserDefined(appInstance *v1.AppInstance, allowedLabels, allowedAnnota
 		appInstance.Status.AppSpec.Volumes[key] = v
 	}
 
+	for key, s := range appInstance.Status.AppSpec.Services {
+		labels := v1.ScopedLabels{}
+		annotations := v1.ScopedLabels{}
+		for _, v := range s.Labels {
+			if slices.Contains(allowedLabels, v.Key) {
+				labels = append(labels, v)
+			}
+		}
+		for _, v := range s.Annotations {
+			if slices.Contains(allowedAnnotations, v.Key) {
+				annotations = append(annotations, v)
+			}
+		}
+		s.Labels = labels
+		s.Annotations = annotations
+		appInstance.Status.AppSpec.Services[key] = s
+	}
+
 	return appInstance
 }
 
