@@ -16,8 +16,13 @@ import (
 var (
 	SHAPermissivePrefixPattern = regexp.MustCompile(`^[a-f\d]{3,64}$`)
 	SHAPattern                 = regexp.MustCompile(`^[a-f\d]{64}$`)
+	DigestPattern              = regexp.MustCompile(`^sha256:[a-f\d]{64}$`)
 )
 
+func IsImageDigest(s string) bool {
+	return DigestPattern.MatchString(s)
+}
+
 func IsLocalReference(image string) bool {
 	if strings.HasPrefix(image, "sha256:") {
 		return true
@@ -48,6 +53,9 @@ func GetTagsMatchingRepository(ctx context.Context, reference name.Reference, c
 	}
 	var result []string
 	for _, image := range images.Items {
+		if image.Remote {
+			continue
+		}
 		for _, tag := range image.Tags {
 			r, err := name.ParseReference(tag, name.WithDefaultRegistry(defaultReg))
 			if err != nil {
@@ -64,6 +72,7 @@ func GetTagsMatchingRepository(ctx context.Context, reference name.Reference, c
 // ResolveLocal determines if the image is local and if it is, resolves it to an image ID that can be pulled from the
 // local registry
 func ResolveLocal(ctx context.Context, c kclient.Client, namespace, image string) (string, bool, error) {
+	// use apiv1.Image here so that get logic does the resolution of names, tags, digests etc
 	localImage := &apiv1.Image{}
 
 	err := c.Get(ctx, kclient.ObjectKey{
@@ -75,10 +84,9 @@ func ResolveLocal(ctx context.Context, c kclient.Client, namespace, image string
 		if IsLocalReference(image) {
 			return "", false, err
 		}
+		return image, false, nil
 	} else if err != nil {
 		return "", false, err
-	} else {
-		return strings.TrimPrefix(localImage.Digest, "sha256:"), true, nil
 	}
-	return image, false, nil
+	return strings.TrimPrefix(localImage.Digest, "sha256:"), !localImage.Remote, nil
 }
