@@ -25,7 +25,7 @@ func App(ctx context.Context, c client.Client, appName string, quiet bool) error
 		wg.Add(1)
 		go func() {
 			defer wg.Done()
-			_ = dev.AppStatusLoop(ctx, c, app)
+			_ = dev.AppStatusLoop(ctx, c, app.Name)
 		}()
 	}
 
@@ -51,9 +51,9 @@ func waitForApp(ctx context.Context, c client.Client, app *apiv1.App) (*apiv1.Ap
 		if app.Status.Ready && app.Generation == app.Status.ObservedGeneration {
 			return true, nil
 		}
-		for name, job := range app.Status.JobsStatus {
-			if job.Failed {
-				return false, fmt.Errorf("job %s failed: %s", name, job.Message)
+		for name, job := range app.Status.AppStatus.Jobs {
+			if !job.Ready && job.RunningCount == 0 && job.ErrorCount > 0 && len(job.ErrorMessages) > 0 {
+				return false, fmt.Errorf("job %s failed: %s", name, job.ErrorMessages)
 			}
 		}
 		return false, nil
